@@ -1,10 +1,10 @@
 /// <reference types="node" />
 
-import childProcess = require('child_process');
-import fs = require('fs-extra');
-import path = require('path');
-import removeInternal = require('remove-internal');
-import glob = require('glob');
+import childProcess = require("child_process");
+import fs = require("fs-extra");
+import path = require("path");
+import removeInternal = require("remove-internal");
+import glob = require("glob");
 
 const root = path.join(__dirname, "..");
 const source = path.join(root, "built/local");
@@ -27,10 +27,14 @@ async function copyLibFiles() {
 
 async function copyLocalizedDiagnostics() {
     const dir = await fs.readdir(source);
+    const ignoredFolders = ["enu"];
+
     for (const d of dir) {
         const fileName = path.join(source, d);
-        if (fs.statSync(fileName).isDirectory()) {
-            if (d === 'tslint' || d === 'enu') continue;
+        if (
+            fs.statSync(fileName).isDirectory() &&
+            ignoredFolders.indexOf(d) < 0
+        ) {
             await fs.copy(fileName, path.join(dest, d));
         }
     }
