@@ -7,6 +7,11 @@ namespace ts {
         AsyncMethodsWithSuper = 1 << 0
     }
 
+    const enum ContextFlags {
+        NonTopLevel = 1 << 0,
+        HasLexicalThis = 1 << 1
+    }
+
     export function transformES2017(context: TransformationContext) {
         const {
             resumeLexicalEnvironment,
@@ -41,7 +46,7 @@ namespace ts {
         /** A set of node IDs for generated super accessors (variable statements). */
         const substitutedSuperAccessors: boolean[] = [];
 
-        let topLevel: boolean;
+        let contextFlags: ContextFlags = 0;
 
         // Save the previous transformation hooks.
         const previousOnEmitNode = context.onEmitNode;
@@ -58,17 +63,35 @@ namespace ts {
                 return node;
             }
 
-            topLevel = isEffectiveStrictModeSourceFile(node, compilerOptions);
+            setContextFlag(ContextFlags.NonTopLevel, false);
+            setContextFlag(ContextFlags.HasLexicalThis, !isEffectiveStrictModeSourceFile(node, compilerOptions));
             const visited = visitEachChild(node, visitor, context);
             addEmitHelpers(visited, context.readEmitHelpers());
             return visited;
         }
 
-        function doOutsideOfTopLevel<T, U>(cb: (value: T) => U, value: T) {
-            if (topLevel) {
-                topLevel = false;
+        function setContextFlag(flag: ContextFlags, val: boolean) {
+            contextFlags = val ? contextFlags | flag : contextFlags & ~flag;
+        }
+
+        function inContext(flags: ContextFlags) {
+            return (contextFlags & flags) !== 0;
+        }
+
+        function inTopLevelContext() {
+            return !inContext(ContextFlags.NonTopLevel);
+        }
+
+        function inHasLexicalThisContext() {
+            return inContext(ContextFlags.HasLexicalThis);
+        }
+
+        function doWithContext<T, U>(flags: ContextFlags, cb: (value: T) => U, value: T) {
+            const contextFlagsToSet = flags & ~contextFlags;
+            if (contextFlagsToSet) {
+                setContextFlag(contextFlagsToSet, /*val*/ true);
                 const result = cb(value);
-                topLevel = true;
+                setContextFlag(contextFlagsToSet, /*val*/ false);
                 return result;
             }
             return cb(value);
@@ -91,16 +114,16 @@ namespace ts {
                     return visitAwaitExpression(<AwaitExpression>node);
 
                 case SyntaxKind.MethodDeclaration:
-                    return doOutsideOfTopLevel(visitMethodDeclaration, <MethodDeclaration>node);
+                    return doWithContext(ContextFlags.NonTopLevel | ContextFlags.HasLexicalThis, visitMethodDeclaration, <MethodDeclaration>node);
 
                 case SyntaxKind.FunctionDeclaration:
-                    return doOutsideOfTopLevel(visitFunctionDeclaration, <FunctionDeclaration>node);
+                    return doWithContext(ContextFlags.NonTopLevel | ContextFlags.HasLexicalThis, visitFunctionDeclaration, <FunctionDeclaration>node);
 
                 case SyntaxKind.FunctionExpression:
-                    return doOutsideOfTopLevel(visitFunctionExpression, <FunctionExpression>node);
+                    return doWithContext(ContextFlags.NonTopLevel | ContextFlags.HasLexicalThis, visitFunctionExpression, <FunctionExpression>node);
 
                 case SyntaxKind.ArrowFunction:
-                    return visitArrowFunction(<ArrowFunction>node);
+                    return doWithContext(ContextFlags.NonTopLevel, visitArrowFunction, <ArrowFunction>node);
 
                 case SyntaxKind.PropertyAccessExpression:
                     if (capturedSuperProperties && isPropertyAccessExpression(node) && node.expression.kind === SyntaxKind.SuperKeyword) {
@@ -119,7 +142,7 @@ namespace ts {
                 case SyntaxKind.Constructor:
                 case SyntaxKind.ClassDeclaration:
                 case SyntaxKind.ClassExpression:
-                    return doOutsideOfTopLevel(visitDefault, node);
+                    return doWithContext(ContextFlags.NonTopLevel | ContextFlags.HasLexicalThis, visitDefault, node);
 
                 default:
                     return visitEachChild(node, visitor, context);
@@ -237,6 +260,10 @@ namespace ts {
          * @param node The node to visit.
          */
         function visitAwaitExpression(node: AwaitExpression): Expression {
+            // do not downlevel a top-level await as it is module syntax...
+            if (inTopLevelContext()) {
+                return visitEachChild(node, visitor, context);
+            }
             return setOriginalNode(
                 setTextRange(
                     createYield(
@@ -457,7 +484,7 @@ namespace ts {
                     createReturn(
                         createAwaiterHelper(
                             context,
-                            !topLevel,
+                            inHasLexicalThisContext(),
                             hasLexicalArguments,
                             promiseConstructor,
                             transformAsyncFunctionBodyWorker(<Block>node.body, statementOffset)
@@ -498,7 +525,7 @@ namespace ts {
             else {
                 const expression = createAwaiterHelper(
                     context,
-                    !topLevel,
+                    inHasLexicalThisContext(),
                     hasLexicalArguments,
                     promiseConstructor,
                     transformAsyncFunctionBodyWorker(node.body!)
