@@ -82,6 +82,9 @@ namespace ts {
          * @param node A PropertyAccessExpression
          */
         function substitutePropertyAccessExpression(node: PropertyAccessExpression): Expression {
+            if (isPrivateIdentifier(node.name)) {
+                return node;
+            }
             const literalName = trySubstituteReservedName(node.name);
             if (literalName) {
                 return setTextRange(createElementAccess(node.expression, literalName), node);
