@@ -68,7 +68,9 @@ namespace ts.codefix {
                     makeChange(t, errorCode, sourceFile, checker, expression, fixedDeclarations);
                 }
             });
-            return createCodeFixActionNoFixId(
+            // No fix-all because it will already be included once with the use site fix,
+            // and for simplicity the fix-all doesn‘t let the user choose between use-site and declaration-site fixes.
+            return createCodeFixActionWithoutFixAll(
                 "addMissingAwaitToInitializer",
                 initializerChanges,
                 awaitableInitializers.initializers.length === 1
@@ -257,6 +259,7 @@ namespace ts.codefix {
                 sourceFile,
                 insertionSite.parent.expression,
                 createParen(createAwait(insertionSite.parent.expression)));
+            insertLeadingSemicolonIfNeeded(changeTracker, insertionSite.parent.expression, sourceFile);
         }
         else if (contains(callableConstructableErrorCodes, errorCode) && isCallOrNewExpression(insertionSite.parent)) {
             if (fixedDeclarations && isIdentifier(insertionSite)) {
@@ -266,6 +269,7 @@ namespace ts.codefix {
                 }
             }
             changeTracker.replaceNode(sourceFile, insertionSite, createParen(createAwait(insertionSite)));
+            insertLeadingSemicolonIfNeeded(changeTracker, insertionSite, sourceFile);
         }
         else {
             if (fixedDeclarations && isVariableDeclaration(insertionSite.parent) && isIdentifier(insertionSite.parent.name)) {
@@ -277,4 +281,11 @@ namespace ts.codefix {
             changeTracker.replaceNode(sourceFile, insertionSite, createAwait(insertionSite));
         }
     }
+
+    function insertLeadingSemicolonIfNeeded(changeTracker: textChanges.ChangeTracker, beforeNode: Node, sourceFile: SourceFile) {
+        const precedingToken = findPrecedingToken(beforeNode.pos, sourceFile);
+        if (precedingToken && positionIsASICandidate(precedingToken.end, precedingToken.parent, sourceFile)) {
+            changeTracker.insertText(sourceFile, beforeNode.getStart(sourceFile), ";");
+        }
+    }
 }
