@@ -70,8 +70,8 @@ namespace ts.formatting {
             rule("NoSpaceAfterUnaryPrefixOperator", unaryPrefixOperators, unaryPrefixExpressions, [isNonJsxSameLineTokenContext, isNotBinaryOpContext], RuleAction.DeleteSpace),
             rule("NoSpaceAfterUnaryPreincrementOperator", SyntaxKind.PlusPlusToken, unaryPreincrementExpressions, [isNonJsxSameLineTokenContext], RuleAction.DeleteSpace),
             rule("NoSpaceAfterUnaryPredecrementOperator", SyntaxKind.MinusMinusToken, unaryPredecrementExpressions, [isNonJsxSameLineTokenContext], RuleAction.DeleteSpace),
-            rule("NoSpaceBeforeUnaryPostincrementOperator", unaryPostincrementExpressions, SyntaxKind.PlusPlusToken, [isNonJsxSameLineTokenContext], RuleAction.DeleteSpace),
-            rule("NoSpaceBeforeUnaryPostdecrementOperator", unaryPostdecrementExpressions, SyntaxKind.MinusMinusToken, [isNonJsxSameLineTokenContext], RuleAction.DeleteSpace),
+            rule("NoSpaceBeforeUnaryPostincrementOperator", unaryPostincrementExpressions, SyntaxKind.PlusPlusToken, [isNonJsxSameLineTokenContext, isNotStatementConditionContext], RuleAction.DeleteSpace),
+            rule("NoSpaceBeforeUnaryPostdecrementOperator", unaryPostdecrementExpressions, SyntaxKind.MinusMinusToken, [isNonJsxSameLineTokenContext, isNotStatementConditionContext], RuleAction.DeleteSpace),
 
             // More unary operator special-casing.
             // DevDiv 181814: Be careful when removing leading whitespace
@@ -433,9 +433,9 @@ namespace ts.formatting {
     }
 
     function isBinaryOpContext(context: FormattingContext): boolean {
-
         switch (context.contextNode.kind) {
             case SyntaxKind.BinaryExpression:
+                return (<BinaryExpression>context.contextNode).operatorToken.kind !== SyntaxKind.CommaToken;
             case SyntaxKind.ConditionalExpression:
             case SyntaxKind.ConditionalType:
             case SyntaxKind.AsExpression:
@@ -790,6 +790,25 @@ namespace ts.formatting {
         return context.contextNode.kind === SyntaxKind.NonNullExpression;
     }
 
+    function isNotStatementConditionContext(context: FormattingContext): boolean {
+        return !isStatementConditionContext(context);
+    }
+
+    function isStatementConditionContext(context: FormattingContext): boolean {
+        switch (context.contextNode.kind) {
+            case SyntaxKind.IfStatement:
+            case SyntaxKind.ForStatement:
+            case SyntaxKind.ForInStatement:
+            case SyntaxKind.ForOfStatement:
+            case SyntaxKind.DoStatement:
+            case SyntaxKind.WhileStatement:
+                return true;
+
+            default:
+                return false;
+        }
+    }
+
     function isSemicolonDeletionContext(context: FormattingContext): boolean {
         let nextTokenKind = context.nextTokenSpan.kind;
         let nextTokenStart = context.nextTokenSpan.pos;
@@ -855,13 +874,6 @@ namespace ts.formatting {
     }
 
     function isSemicolonInsertionContext(context: FormattingContext): boolean {
-        const contextAncestor = findAncestor(context.currentTokenParent, ancestor => {
-            if (ancestor.end !== context.currentTokenSpan.end) {
-                return "quit";
-            }
-            return syntaxMayBeASICandidate(ancestor.kind);
-        });
-
-        return !!contextAncestor && isASICandidate(contextAncestor, context.sourceFile);
+        return positionIsASICandidate(context.currentTokenSpan.end, context.currentTokenParent, context.sourceFile);
     }
 }
