@@ -34,7 +34,8 @@ namespace ts.formatting {
 
             const precedingToken = findPrecedingToken(position, sourceFile, /*startNode*/ undefined, /*excludeJsdoc*/ true);
 
-            const enclosingCommentRange = getRangeOfEnclosingComment(sourceFile, position, precedingToken || null); // tslint:disable-line:no-null-keyword
+            // eslint-disable-next-line no-null/no-null
+            const enclosingCommentRange = getRangeOfEnclosingComment(sourceFile, position, precedingToken || null);
             if (enclosingCommentRange && enclosingCommentRange.kind === SyntaxKind.MultiLineCommentTrivia) {
                 return getCommentIndent(sourceFile, position, options, enclosingCommentRange);
             }
@@ -325,8 +326,9 @@ namespace ts.formatting {
         export function argumentStartsOnSameLineAsPreviousArgument(parent: Node, child: TextRangeWithKind, childStartLine: number, sourceFile: SourceFileLike): boolean {
             if (isCallOrNewExpression(parent)) {
                 if (!parent.arguments) return false;
-
-                const currentNode = Debug.assertDefined(find(parent.arguments, arg => arg.pos === child.pos));
+                const currentNode = find(parent.arguments, arg => arg.pos === child.pos);
+                // If it's not one of the arguments, don't look past this
+                if (!currentNode) return false;
                 const currentIndex = parent.arguments.indexOf(currentNode);
                 if (currentIndex === 0) return false; // Can't look at previous node if first
 
@@ -429,7 +431,7 @@ namespace ts.formatting {
             return Value.Unknown;
         }
 
-        function deriveActualIndentationFromList(list: ReadonlyArray<Node>, index: number, sourceFile: SourceFile, options: EditorSettings): number {
+        function deriveActualIndentationFromList(list: readonly Node[], index: number, sourceFile: SourceFile, options: EditorSettings): number {
             Debug.assert(index >= 0 && index < list.length);
             const node = list[index];
 
@@ -539,10 +541,14 @@ namespace ts.formatting {
                     return true;
                 case SyntaxKind.VariableDeclaration:
                 case SyntaxKind.PropertyAssignment:
+                case SyntaxKind.BinaryExpression:
                     if (!settings.indentMultiLineObjectLiteralBeginningOnBlankLine && sourceFile && childKind === SyntaxKind.ObjectLiteralExpression) { // TODO: GH#18217
                         return rangeIsOnOneLine(sourceFile, child!);
                     }
-                    return true;
+                    if (parent.kind !== SyntaxKind.BinaryExpression) {
+                        return true;
+                    }
+                    break;
                 case SyntaxKind.DoStatement:
                 case SyntaxKind.WhileStatement:
                 case SyntaxKind.ForInStatement:
