@@ -1,5 +1,3 @@
-/// <reference path="..\compiler\transformer.ts"/>
-/// <reference path="transpile.ts"/>
 namespace ts {
     /**
      * Transform one or more nodes using the supplied transformers.
@@ -8,8 +6,8 @@ namespace ts {
      * @param compilerOptions Optional compiler options.
      */
     export function transform<T extends Node>(source: T | T[], transformers: TransformerFactory<T>[], compilerOptions?: CompilerOptions) {
-        const diagnostics: Diagnostic[] = [];
-        compilerOptions = fixupCompilerOptions(compilerOptions, diagnostics);
+        const diagnostics: DiagnosticWithLocation[] = [];
+        compilerOptions = fixupCompilerOptions(compilerOptions!, diagnostics); // TODO: GH#18217
         const nodes = isArray(source) ? source : [source];
         const result = transformNodes(/*resolver*/ undefined, /*emitHost*/ undefined, compilerOptions, nodes, transformers, /*allowDtsFiles*/ true);
         result.diagnostics = concatenate(result.diagnostics, diagnostics);
