@@ -11,7 +11,7 @@ namespace Harness.Parallel.Host {
         const isatty = tty.isatty(1) && tty.isatty(2);
         const path = require("path") as typeof import("path");
         const { fork } = require("child_process") as typeof import("child_process");
-        const { statSync, readFileSync } = require("fs") as typeof import("fs");
+        const { statSync } = require("fs") as typeof import("fs");
 
         // NOTE: paths for module and types for FailedTestReporter _do not_ line up due to our use of --outFile for run.js
         const FailedTestReporter = require(path.resolve(__dirname, "../../scripts/failed-tests")) as typeof import("../../../scripts/failed-tests");
@@ -186,31 +186,6 @@ namespace Harness.Parallel.Host {
             return `tsrunner-${runner}://${test}`;
         }
 
-        function skipCostlyTests(tasks: Task[]) {
-            if (statSync("tests/.test-cost.json")) {
-                const costs = JSON.parse(readFileSync("tests/.test-cost.json", "utf8")) as {
-                    totalTime: number,
-                    totalEdits: number,
-                    data: { name: string, time: number, edits: number, costs: number }[]
-                };
-                let skippedEdits = 0;
-                let skippedTime = 0;
-                const skippedTests = new Set<string>();
-                let i = 0;
-                for (; i < costs.data.length && (skippedEdits / costs.totalEdits) < (skipPercent / 100); i++) {
-                    skippedEdits += costs.data[i].edits;
-                    skippedTime += costs.data[i].time;
-                    skippedTests.add(costs.data[i].name);
-                }
-                console.log(`Skipped ${i} expensive tests; estimated time savings of ${(skippedTime / costs.totalTime * 100).toFixed(2)}% with --skipPercent=${skipPercent.toFixed(2)} chance of missing a test.`);
-                return tasks.filter(t => !skippedTests.has(t.file));
-            }
-            else {
-                console.log("No cost analysis discovered.");
-                return tasks;
-            }
-        }
-
         function startDelayed(perfData: { [testHash: string]: number } | undefined, totalCost: number) {
             console.log(`Discovered ${tasks.length} unittest suites` + (newTasks.length ? ` and ${newTasks.length} new suites.` : "."));
             console.log("Discovering runner-based tests...");
@@ -250,7 +225,6 @@ namespace Harness.Parallel.Host {
             }
             tasks.sort((a, b) => a.size - b.size);
             tasks = tasks.concat(newTasks);
-            tasks = skipCostlyTests(tasks);
             const batchCount = workerCount;
             const packfraction = 0.9;
             const chunkSize = 1000; // ~1KB or 1s for sending batches near the end of a test
@@ -266,7 +240,7 @@ namespace Harness.Parallel.Host {
             let totalPassing = 0;
             const startDate = new Date();
 
-            const progressBars = new ProgressBars({ noColors });
+            const progressBars = new ProgressBars({ noColors: Harness.noColors }); // eslint-disable-line @typescript-eslint/no-unnecessary-qualifier
             const progressUpdateInterval = 1 / progressBars._options.width;
             let nextProgress = progressUpdateInterval;
 
@@ -276,7 +250,7 @@ namespace Harness.Parallel.Host {
             let closedWorkers = 0;
             for (let i = 0; i < workerCount; i++) {
                 // TODO: Just send the config over the IPC channel or in the command line arguments
-                const config: TestConfig = { light: lightMode, listenForWork: true, runUnitTests, stackTraceLimit, timeout: globalTimeout };
+                const config: TestConfig = { light: lightMode, listenForWork: true, runUnitTests: Harness.runUnitTests, stackTraceLimit: Harness.stackTraceLimit, timeout: globalTimeout }; // eslint-disable-line @typescript-eslint/no-unnecessary-qualifier
                 const configPath = ts.combinePaths(taskConfigsFolder, `task-config${i}.json`);
                 IO.writeFile(configPath, JSON.stringify(config));
                 const worker: Worker = {
@@ -575,7 +549,7 @@ namespace Harness.Parallel.Host {
                     failedTestReporter = new FailedTestReporter(replayRunner, {
                         reporterOptions: {
                             file: path.resolve(".failed-tests"),
-                            keepFailed
+                            keepFailed: Harness.keepFailed // eslint-disable-line @typescript-eslint/no-unnecessary-qualifier
                         }
                     });
                 }
