@@ -1,11 +1,10 @@
 namespace ts {
     describe("unittests:: config:: commandLineParsing:: parseCommandLine", () => {
 
-        function assertParseResult(commandLine: string[], expectedParsedCommandLine: ParsedCommandLine) {
-            const parsed = parseCommandLine(commandLine);
-            const parsedCompilerOptions = JSON.stringify(parsed.options);
-            const expectedCompilerOptions = JSON.stringify(expectedParsedCommandLine.options);
-            assert.equal(parsedCompilerOptions, expectedCompilerOptions);
+        function assertParseResult(commandLine: string[], expectedParsedCommandLine: ParsedCommandLine, workerDiagnostic?: () => ParseCommandLineWorkerDiagnostics) {
+            const parsed = parseCommandLineWorker(workerDiagnostic?.() || compilerOptionsDidYouMeanDiagnostics, commandLine);
+            assert.deepEqual(parsed.options, expectedParsedCommandLine.options);
+            assert.deepEqual(parsed.watchOptions, expectedParsedCommandLine.watchOptions);
 
             const parsedErrors = parsed.errors;
             const expectedErrors = expectedParsedCommandLine.errors;
@@ -40,6 +39,33 @@ namespace ts {
                 });
         });
 
+        it("Handles 'did you mean?' for misspelt flags", () => {
+            // --declarations --allowTS
+            assertParseResult(["--declarations", "--allowTS"], {
+                errors: [
+                    {
+                        messageText: "Unknown compiler option '--declarations'. Did you mean 'declaration'?",
+                        category: Diagnostics.Unknown_compiler_option_0_Did_you_mean_1.category,
+                        code: Diagnostics.Unknown_compiler_option_0_Did_you_mean_1.code,
+                        file: undefined,
+                        start: undefined,
+                        length: undefined
+                    },
+                    {
+                        messageText: "Unknown compiler option '--allowTS'. Did you mean 'allowJs'?",
+                        category: Diagnostics.Unknown_compiler_option_0_Did_you_mean_1.category,
+                        code: Diagnostics.Unknown_compiler_option_0_Did_you_mean_1.code,
+                        file: undefined,
+                        start: undefined,
+                        length: undefined
+                    }
+                ],
+                fileNames: [],
+                options: {}
+            });
+        });
+
+
         it("Parse multiple options of library flags ", () => {
             // --lib es5,es2015.symbol.wellknown 0.ts
             assertParseResult(["--lib", "es5,es2015.symbol.wellknown", "0.ts"],
@@ -57,7 +83,7 @@ namespace ts {
             assertParseResult(["--lib", "es5,invalidOption", "0.ts"],
                 {
                     errors: [{
-                        messageText: "Argument for '--lib' option must be: 'es5', 'es6', 'es2015', 'es7', 'es2016', 'es2017', 'es2018', 'es2019', 'es2020', 'esnext', 'dom', 'dom.iterable', 'webworker', 'webworker.importscripts', 'scripthost', 'es2015.core', 'es2015.collection', 'es2015.generator', 'es2015.iterable', 'es2015.promise', 'es2015.proxy', 'es2015.reflect', 'es2015.symbol', 'es2015.symbol.wellknown', 'es2016.array.include', 'es2017.object', 'es2017.sharedmemory', 'es2017.string', 'es2017.intl', 'es2017.typedarrays', 'es2018.asyncgenerator', 'es2018.asynciterable', 'es2018.intl', 'es2018.promise', 'es2018.regexp', 'es2019.array', 'es2019.object', 'es2019.string', 'es2019.symbol', 'es2020.string', 'es2020.symbol.wellknown', 'esnext.array', 'esnext.symbol', 'esnext.asynciterable', 'esnext.intl', 'esnext.bigint'.",
+                        messageText: "Argument for '--lib' option must be: 'es5', 'es6', 'es2015', 'es7', 'es2016', 'es2017', 'es2018', 'es2019', 'es2020', 'esnext', 'dom', 'dom.iterable', 'webworker', 'webworker.importscripts', 'scripthost', 'es2015.core', 'es2015.collection', 'es2015.generator', 'es2015.iterable', 'es2015.promise', 'es2015.proxy', 'es2015.reflect', 'es2015.symbol', 'es2015.symbol.wellknown', 'es2016.array.include', 'es2017.object', 'es2017.sharedmemory', 'es2017.string', 'es2017.intl', 'es2017.typedarrays', 'es2018.asyncgenerator', 'es2018.asynciterable', 'es2018.intl', 'es2018.promise', 'es2018.regexp', 'es2019.array', 'es2019.object', 'es2019.string', 'es2019.symbol', 'es2020.bigint', 'es2020.promise', 'es2020.string', 'es2020.symbol.wellknown', 'esnext.array', 'esnext.symbol', 'esnext.asynciterable', 'esnext.intl', 'esnext.bigint'.",
                         category: Diagnostics.Argument_for_0_option_must_be_Colon_1.category,
                         code: Diagnostics.Argument_for_0_option_must_be_Colon_1.code,
                         file: undefined,
@@ -92,7 +118,7 @@ namespace ts {
                         length: undefined,
                     }],
                     fileNames: ["0.ts"],
-                    options: {}
+                    options: { jsx: undefined }
                 });
         });
 
@@ -109,7 +135,7 @@ namespace ts {
                         start: undefined,
                         length: undefined,
                     }, {
-                        messageText: "Argument for '--module' option must be: 'none', 'commonjs', 'amd', 'system', 'umd', 'es6', 'es2015', 'esnext'.",
+                        messageText: "Argument for '--module' option must be: 'none', 'commonjs', 'amd', 'system', 'umd', 'es6', 'es2015', 'es2020', 'esnext'.",
                         category: Diagnostics.Argument_for_0_option_must_be_Colon_1.category,
                         code: Diagnostics.Argument_for_0_option_must_be_Colon_1.code,
 
@@ -118,7 +144,7 @@ namespace ts {
                         length: undefined,
                     }],
                     fileNames: ["0.ts"],
-                    options: {}
+                    options: { module: undefined }
                 });
         });
 
@@ -144,7 +170,7 @@ namespace ts {
                         length: undefined,
                     }],
                     fileNames: ["0.ts"],
-                    options: {}
+                    options: { newLine: undefined }
                 });
         });
 
@@ -170,7 +196,7 @@ namespace ts {
                         length: undefined,
                     }],
                     fileNames: ["0.ts"],
-                    options: {}
+                    options: { target: undefined }
                 });
         });
 
@@ -196,7 +222,7 @@ namespace ts {
                         length: undefined,
                     }],
                     fileNames: ["0.ts"],
-                    options: {}
+                    options: { moduleResolution: undefined }
                 });
         });
 
@@ -259,7 +285,7 @@ namespace ts {
             assertParseResult(["--lib", "es5,", "es7", "0.ts"],
                 {
                     errors: [{
-                        messageText: "Argument for '--lib' option must be: 'es5', 'es6', 'es2015', 'es7', 'es2016', 'es2017', 'es2018', 'es2019', 'es2020', 'esnext', 'dom', 'dom.iterable', 'webworker', 'webworker.importscripts', 'scripthost', 'es2015.core', 'es2015.collection', 'es2015.generator', 'es2015.iterable', 'es2015.promise', 'es2015.proxy', 'es2015.reflect', 'es2015.symbol', 'es2015.symbol.wellknown', 'es2016.array.include', 'es2017.object', 'es2017.sharedmemory', 'es2017.string', 'es2017.intl', 'es2017.typedarrays', 'es2018.asyncgenerator', 'es2018.asynciterable', 'es2018.intl', 'es2018.promise', 'es2018.regexp', 'es2019.array', 'es2019.object', 'es2019.string', 'es2019.symbol', 'es2020.string', 'es2020.symbol.wellknown', 'esnext.array', 'esnext.symbol', 'esnext.asynciterable', 'esnext.intl', 'esnext.bigint'.",
+                        messageText: "Argument for '--lib' option must be: 'es5', 'es6', 'es2015', 'es7', 'es2016', 'es2017', 'es2018', 'es2019', 'es2020', 'esnext', 'dom', 'dom.iterable', 'webworker', 'webworker.importscripts', 'scripthost', 'es2015.core', 'es2015.collection', 'es2015.generator', 'es2015.iterable', 'es2015.promise', 'es2015.proxy', 'es2015.reflect', 'es2015.symbol', 'es2015.symbol.wellknown', 'es2016.array.include', 'es2017.object', 'es2017.sharedmemory', 'es2017.string', 'es2017.intl', 'es2017.typedarrays', 'es2018.asyncgenerator', 'es2018.asynciterable', 'es2018.intl', 'es2018.promise', 'es2018.regexp', 'es2019.array', 'es2019.object', 'es2019.string', 'es2019.symbol', 'es2020.bigint', 'es2020.promise', 'es2020.string', 'es2020.symbol.wellknown', 'esnext.array', 'esnext.symbol', 'esnext.asynciterable', 'esnext.intl', 'esnext.bigint'.",
                         category: Diagnostics.Argument_for_0_option_must_be_Colon_1.category,
                         code: Diagnostics.Argument_for_0_option_must_be_Colon_1.code,
                         file: undefined,
@@ -278,7 +304,7 @@ namespace ts {
             assertParseResult(["--lib", "es5, ", "es7", "0.ts"],
                 {
                     errors: [{
-                        messageText: "Argument for '--lib' option must be: 'es5', 'es6', 'es2015', 'es7', 'es2016', 'es2017', 'es2018', 'es2019', 'es2020', 'esnext', 'dom', 'dom.iterable', 'webworker', 'webworker.importscripts', 'scripthost', 'es2015.core', 'es2015.collection', 'es2015.generator', 'es2015.iterable', 'es2015.promise', 'es2015.proxy', 'es2015.reflect', 'es2015.symbol', 'es2015.symbol.wellknown', 'es2016.array.include', 'es2017.object', 'es2017.sharedmemory', 'es2017.string', 'es2017.intl', 'es2017.typedarrays', 'es2018.asyncgenerator', 'es2018.asynciterable', 'es2018.intl', 'es2018.promise', 'es2018.regexp', 'es2019.array', 'es2019.object', 'es2019.string', 'es2019.symbol', 'es2020.string', 'es2020.symbol.wellknown', 'esnext.array', 'esnext.symbol', 'esnext.asynciterable', 'esnext.intl', 'esnext.bigint'.",
+                        messageText: "Argument for '--lib' option must be: 'es5', 'es6', 'es2015', 'es7', 'es2016', 'es2017', 'es2018', 'es2019', 'es2020', 'esnext', 'dom', 'dom.iterable', 'webworker', 'webworker.importscripts', 'scripthost', 'es2015.core', 'es2015.collection', 'es2015.generator', 'es2015.iterable', 'es2015.promise', 'es2015.proxy', 'es2015.reflect', 'es2015.symbol', 'es2015.symbol.wellknown', 'es2016.array.include', 'es2017.object', 'es2017.sharedmemory', 'es2017.string', 'es2017.intl', 'es2017.typedarrays', 'es2018.asyncgenerator', 'es2018.asynciterable', 'es2018.intl', 'es2018.promise', 'es2018.regexp', 'es2019.array', 'es2019.object', 'es2019.string', 'es2019.symbol', 'es2020.bigint', 'es2020.promise', 'es2020.string', 'es2020.symbol.wellknown', 'esnext.array', 'esnext.symbol', 'esnext.asynciterable', 'esnext.intl', 'esnext.bigint'.",
                         category: Diagnostics.Argument_for_0_option_must_be_Colon_1.category,
                         code: Diagnostics.Argument_for_0_option_must_be_Colon_1.code,
                         file: undefined,
@@ -385,14 +411,259 @@ namespace ts {
                     options: { tsBuildInfoFile: "build.tsbuildinfo" }
                 });
         });
+
+        describe("parses command line null for tsconfig only option", () => {
+            interface VerifyNull {
+                optionName: string;
+                nonNullValue?: string;
+                workerDiagnostic?: () => ParseCommandLineWorkerDiagnostics;
+                diagnosticMessage: DiagnosticMessage;
+            }
+            function verifyNull({ optionName, nonNullValue, workerDiagnostic, diagnosticMessage }: VerifyNull) {
+                it("allows setting it to null", () => {
+                    assertParseResult(
+                        [`--${optionName}`, "null", "0.ts"],
+                        {
+                            errors: [],
+                            fileNames: ["0.ts"],
+                            options: { [optionName]: undefined }
+                        },
+                        workerDiagnostic
+                    );
+                });
+
+                if (nonNullValue) {
+                    it("errors if non null value is passed", () => {
+                        assertParseResult(
+                            [`--${optionName}`, nonNullValue, "0.ts"],
+                            {
+                                errors: [{
+                                    messageText: formatStringFromArgs(diagnosticMessage.message, [optionName]),
+                                    category: diagnosticMessage.category,
+                                    code: diagnosticMessage.code,
+                                    file: undefined,
+                                    start: undefined,
+                                    length: undefined
+                                }],
+                                fileNames: ["0.ts"],
+                                options: {}
+                            },
+                            workerDiagnostic
+                        );
+                    });
+                }
+
+                it("errors if its followed by another option", () => {
+                    assertParseResult(
+                        ["0.ts", "--strictNullChecks", `--${optionName}`],
+                        {
+                            errors: [{
+                                messageText: formatStringFromArgs(diagnosticMessage.message, [optionName]),
+                                category: diagnosticMessage.category,
+                                code: diagnosticMessage.code,
+                                file: undefined,
+                                start: undefined,
+                                length: undefined
+                            }],
+                            fileNames: ["0.ts"],
+                            options: { strictNullChecks: true }
+                        },
+                        workerDiagnostic
+                    );
+                });
+
+                it("errors if its last option", () => {
+                    assertParseResult(
+                        ["0.ts", `--${optionName}`],
+                        {
+                            errors: [{
+                                messageText: formatStringFromArgs(diagnosticMessage.message, [optionName]),
+                                category: diagnosticMessage.category,
+                                code: diagnosticMessage.code,
+                                file: undefined,
+                                start: undefined,
+                                length: undefined
+                            }],
+                            fileNames: ["0.ts"],
+                            options: {}
+                        },
+                        workerDiagnostic
+                    );
+                });
+            }
+
+            interface VerifyNullNonIncludedOption {
+                type: () => "string" | "number" | Map<number | string>;
+                nonNullValue?: string;
+            }
+            function verifyNullNonIncludedOption({ type, nonNullValue }: VerifyNullNonIncludedOption) {
+                verifyNull({
+                    optionName: "optionName",
+                    nonNullValue,
+                    diagnosticMessage: Diagnostics.Option_0_can_only_be_specified_in_tsconfig_json_file_or_set_to_null_on_command_line,
+                    workerDiagnostic: () => {
+                        const optionDeclarations = [
+                            ...compilerOptionsDidYouMeanDiagnostics.optionDeclarations,
+                            {
+                                name: "optionName",
+                                type: type(),
+                                isTSConfigOnly: true,
+                                category: Diagnostics.Basic_Options,
+                                description: Diagnostics.Enable_project_compilation,
+                            }
+                        ];
+                        return {
+                            ...compilerOptionsDidYouMeanDiagnostics,
+                            optionDeclarations,
+                            getOptionsNameMap: () => createOptionNameMap(optionDeclarations)
+                        };
+                    }
+                });
+            }
+
+            describe("option of type boolean", () => {
+                it("allows setting it to false", () => {
+                    assertParseResult(
+                        ["--composite", "false", "0.ts"],
+                        {
+                            errors: [],
+                            fileNames: ["0.ts"],
+                            options: { composite: false }
+                        }
+                    );
+                });
+
+                verifyNull({
+                    optionName: "composite",
+                    nonNullValue: "true",
+                    diagnosticMessage: Diagnostics.Option_0_can_only_be_specified_in_tsconfig_json_file_or_set_to_false_or_null_on_command_line
+                });
+            });
+
+            describe("option of type object", () => {
+                verifyNull({
+                    optionName: "paths",
+                    diagnosticMessage: Diagnostics.Option_0_can_only_be_specified_in_tsconfig_json_file_or_set_to_null_on_command_line
+                });
+            });
+
+            describe("option of type list", () => {
+                verifyNull({
+                    optionName: "rootDirs",
+                    nonNullValue: "abc,xyz",
+                    diagnosticMessage: Diagnostics.Option_0_can_only_be_specified_in_tsconfig_json_file_or_set_to_null_on_command_line
+                });
+            });
+
+            describe("option of type string", () => {
+                verifyNullNonIncludedOption({
+                    type: () => "string",
+                    nonNullValue: "hello"
+                });
+            });
+
+            describe("option of type number", () => {
+                verifyNullNonIncludedOption({
+                    type: () => "number",
+                    nonNullValue: "10"
+                });
+            });
+
+            describe("option of type Map<number | string>", () => {
+                verifyNullNonIncludedOption({
+                    type: () => createMapFromTemplate({
+                        node: ModuleResolutionKind.NodeJs,
+                        classic: ModuleResolutionKind.Classic,
+                    }),
+                    nonNullValue: "node"
+                });
+            });
+        });
+
+        it("allows tsconfig only option to be set to null", () => {
+            assertParseResult(["--composite", "null", "-tsBuildInfoFile", "null", "0.ts"],
+                {
+                    errors: [],
+                    fileNames: ["0.ts"],
+                    options: { composite: undefined, tsBuildInfoFile: undefined }
+                });
+        });
+
+        describe("Watch options", () => {
+            it("parse --watchFile", () => {
+                assertParseResult(["--watchFile", "UseFsEvents", "0.ts"],
+                    {
+                        errors: [],
+                        fileNames: ["0.ts"],
+                        options: {},
+                        watchOptions: { watchFile: WatchFileKind.UseFsEvents }
+                    });
+            });
+
+            it("parse --watchDirectory", () => {
+                assertParseResult(["--watchDirectory", "FixedPollingInterval", "0.ts"],
+                    {
+                        errors: [],
+                        fileNames: ["0.ts"],
+                        options: {},
+                        watchOptions: { watchDirectory: WatchDirectoryKind.FixedPollingInterval }
+                    });
+            });
+
+            it("parse --fallbackPolling", () => {
+                assertParseResult(["--fallbackPolling", "PriorityInterval", "0.ts"],
+                    {
+                        errors: [],
+                        fileNames: ["0.ts"],
+                        options: {},
+                        watchOptions: { fallbackPolling: PollingWatchKind.PriorityInterval }
+                    });
+            });
+
+            it("parse --synchronousWatchDirectory", () => {
+                assertParseResult(["--synchronousWatchDirectory", "0.ts"],
+                    {
+                        errors: [],
+                        fileNames: ["0.ts"],
+                        options: {},
+                        watchOptions: { synchronousWatchDirectory: true }
+                    });
+            });
+
+            it("errors on missing argument to --fallbackPolling", () => {
+                assertParseResult(["0.ts", "--fallbackPolling"],
+                    {
+                        errors: [
+                            {
+                                messageText: "Watch option 'fallbackPolling' requires a value of type string.",
+                                category: Diagnostics.Watch_option_0_requires_a_value_of_type_1.category,
+                                code: Diagnostics.Watch_option_0_requires_a_value_of_type_1.code,
+                                file: undefined,
+                                start: undefined,
+                                length: undefined
+                            },
+                            {
+                                messageText: "Argument for '--fallbackPolling' option must be: 'fixedinterval', 'priorityinterval', 'dynamicpriority'.",
+                                category: Diagnostics.Argument_for_0_option_must_be_Colon_1.category,
+                                code: Diagnostics.Argument_for_0_option_must_be_Colon_1.code,
+                                file: undefined,
+                                start: undefined,
+                                length: undefined
+                            }
+                        ],
+                        fileNames: ["0.ts"],
+                        options: {},
+                        watchOptions: { fallbackPolling: undefined }
+                    });
+            });
+        });
     });
 
     describe("unittests:: config:: commandLineParsing:: parseBuildOptions", () => {
         function assertParseResult(commandLine: string[], expectedParsedBuildCommand: ParsedBuildCommand) {
             const parsed = parseBuildCommand(commandLine);
-            const parsedBuildOptions = JSON.stringify(parsed.buildOptions);
-            const expectedBuildOptions = JSON.stringify(expectedParsedBuildCommand.buildOptions);
-            assert.equal(parsedBuildOptions, expectedBuildOptions);
+            assert.deepEqual(parsed.buildOptions, expectedParsedBuildCommand.buildOptions);
+            assert.deepEqual(parsed.watchOptions, expectedParsedBuildCommand.watchOptions);
 
             const parsedErrors = parsed.errors;
             const expectedErrors = expectedParsedBuildCommand.errors;
@@ -415,7 +686,8 @@ namespace ts {
                 {
                     errors: [],
                     projects: ["."],
-                    buildOptions: {}
+                    buildOptions: {},
+                    watchOptions: undefined
                 });
         });
 
@@ -425,7 +697,8 @@ namespace ts {
                 {
                     errors: [],
                     projects: ["tests"],
-                    buildOptions: { verbose: true, force: true }
+                    buildOptions: { verbose: true, force: true },
+                    watchOptions: undefined
                 });
         });
 
@@ -442,7 +715,8 @@ namespace ts {
                         length: undefined,
                     }],
                     projects: ["."],
-                    buildOptions: { verbose: true }
+                    buildOptions: { verbose: true },
+                    watchOptions: undefined
                 });
         });
 
@@ -451,7 +725,7 @@ namespace ts {
             assertParseResult(["--listFilesOnly"],
                 {
                     errors: [{
-                        messageText:"Unknown build option '--listFilesOnly'.",
+                        messageText: "Unknown build option '--listFilesOnly'.",
                         category: Diagnostics.Unknown_build_option_0.category,
                         code: Diagnostics.Unknown_build_option_0.code,
                         file: undefined,
@@ -459,7 +733,8 @@ namespace ts {
                         length: undefined,
                     }],
                     projects: ["."],
-                    buildOptions: {}
+                    buildOptions: {},
+                    watchOptions: undefined,
                 });
         });
 
@@ -469,7 +744,8 @@ namespace ts {
                 {
                     errors: [],
                     projects: ["src", "tests"],
-                    buildOptions: { force: true, verbose: true }
+                    buildOptions: { force: true, verbose: true },
+                    watchOptions: undefined,
                 });
         });
 
@@ -479,7 +755,8 @@ namespace ts {
                 {
                     errors: [],
                     projects: ["src", "tests"],
-                    buildOptions: { force: true, verbose: true }
+                    buildOptions: { force: true, verbose: true },
+                    watchOptions: undefined,
                 });
         });
 
@@ -489,7 +766,8 @@ namespace ts {
                 {
                     errors: [],
                     projects: ["src", "tests"],
-                    buildOptions: { force: true, verbose: true }
+                    buildOptions: { force: true, verbose: true },
+                    watchOptions: undefined,
                 });
         });
 
@@ -499,7 +777,8 @@ namespace ts {
                 {
                     errors: [],
                     projects: ["tests"],
-                    buildOptions: { incremental: true }
+                    buildOptions: { incremental: true },
+                    watchOptions: undefined,
                 });
         });
 
@@ -509,7 +788,8 @@ namespace ts {
                 {
                     errors: [],
                     projects: ["src"],
-                    buildOptions: { locale: "en-us" }
+                    buildOptions: { locale: "en-us" },
+                    watchOptions: undefined,
                 });
         });
 
@@ -526,7 +806,8 @@ namespace ts {
                         length: undefined
                     }],
                     projects: ["build.tsbuildinfo", "tests"],
-                    buildOptions: { }
+                    buildOptions: {},
+                    watchOptions: undefined,
                 });
         });
 
@@ -545,7 +826,8 @@ namespace ts {
                                 length: undefined,
                             }],
                             projects: ["."],
-                            buildOptions: { [flag1]: true, [flag2]: true }
+                            buildOptions: { [flag1]: true, [flag2]: true },
+                            watchOptions: undefined,
                         });
                 });
             }
@@ -555,5 +837,74 @@ namespace ts {
             verifyInvalidCombination("clean", "watch");
             verifyInvalidCombination("watch", "dry");
         });
+
+        describe("Watch options", () => {
+            it("parse --watchFile", () => {
+                assertParseResult(["--watchFile", "UseFsEvents", "--verbose"],
+                    {
+                        errors: [],
+                        projects: ["."],
+                        buildOptions: { verbose: true },
+                        watchOptions: { watchFile: WatchFileKind.UseFsEvents }
+                    });
+            });
+
+            it("parse --watchDirectory", () => {
+                assertParseResult(["--watchDirectory", "FixedPollingInterval", "--verbose"],
+                    {
+                        errors: [],
+                        projects: ["."],
+                        buildOptions: { verbose: true },
+                        watchOptions: { watchDirectory: WatchDirectoryKind.FixedPollingInterval }
+                    });
+            });
+
+            it("parse --fallbackPolling", () => {
+                assertParseResult(["--fallbackPolling", "PriorityInterval", "--verbose"],
+                    {
+                        errors: [],
+                        projects: ["."],
+                        buildOptions: { verbose: true },
+                        watchOptions: { fallbackPolling: PollingWatchKind.PriorityInterval }
+                    });
+            });
+
+            it("parse --synchronousWatchDirectory", () => {
+                assertParseResult(["--synchronousWatchDirectory", "--verbose"],
+                    {
+                        errors: [],
+                        projects: ["."],
+                        buildOptions: { verbose: true },
+                        watchOptions: { synchronousWatchDirectory: true }
+                    });
+            });
+
+            it("errors on missing argument", () => {
+                assertParseResult(["--verbose", "--fallbackPolling"],
+                    {
+                        errors: [
+                            {
+                                messageText: "Watch option 'fallbackPolling' requires a value of type string.",
+                                category: Diagnostics.Watch_option_0_requires_a_value_of_type_1.category,
+                                code: Diagnostics.Watch_option_0_requires_a_value_of_type_1.code,
+                                file: undefined,
+                                start: undefined,
+                                length: undefined
+                            },
+                            {
+                                messageText: "Argument for '--fallbackPolling' option must be: 'fixedinterval', 'priorityinterval', 'dynamicpriority'.",
+                                category: Diagnostics.Argument_for_0_option_must_be_Colon_1.category,
+                                code: Diagnostics.Argument_for_0_option_must_be_Colon_1.code,
+                                file: undefined,
+                                start: undefined,
+                                length: undefined
+                            }
+                        ],
+                        projects: ["."],
+                        buildOptions: { verbose: true },
+                        watchOptions: { fallbackPolling: undefined }
+                    });
+            });
+        });
     });
 }
