@@ -532,7 +532,14 @@ export = C;
 
     describe("unittests:: moduleResolution:: Files with different casing with forceConsistentCasingInFileNames", () => {
         let library: SourceFile;
-        function test(files: Map<string>, options: CompilerOptions, currentDirectory: string, useCaseSensitiveFileNames: boolean, rootFiles: string[], diagnosticCodes: number[]): void {
+        function test(
+            files: Map<string>,
+            options: CompilerOptions,
+            currentDirectory: string,
+            useCaseSensitiveFileNames: boolean,
+            rootFiles: string[],
+            expectedDiagnostics: (program: Program) => readonly Diagnostic[]
+        ): void {
             const getCanonicalFileName = createGetCanonicalFileName(useCaseSensitiveFileNames);
             if (!useCaseSensitiveFileNames) {
                 const oldFiles = files;
@@ -569,10 +576,7 @@ export = C;
             };
             const program = createProgram(rootFiles, options, host);
             const diagnostics = sortAndDeduplicateDiagnostics([...program.getSemanticDiagnostics(), ...program.getOptionsDiagnostics()]);
-            assert.equal(diagnostics.length, diagnosticCodes.length, `Incorrect number of expected diagnostics, expected ${diagnosticCodes.length}, got '${Harness.Compiler.minimalDiagnosticsToString(diagnostics)}'`);
-            for (let i = 0; i < diagnosticCodes.length; i++) {
-                assert.equal(diagnostics[i].code, diagnosticCodes[i], `Expected diagnostic code ${diagnosticCodes[i]}, got '${diagnostics[i].code}': '${diagnostics[i].messageText}'`);
-            }
+            assert.deepEqual(diagnostics, sortAndDeduplicateDiagnostics(expectedDiagnostics(program)));
         }
 
         it("should succeed when the same file is referenced using absolute and relative names", () => {
@@ -580,7 +584,14 @@ export = C;
                 "/a/b/c.ts": `/// <reference path="d.ts"/>`,
                 "/a/b/d.ts": "var x"
             });
-            test(files, { module: ModuleKind.AMD }, "/a/b", /*useCaseSensitiveFileNames*/ false, ["c.ts", "/a/b/d.ts"], []);
+            test(
+                files,
+                { module: ModuleKind.AMD },
+                "/a/b",
+                /*useCaseSensitiveFileNames*/ false,
+                ["c.ts", "/a/b/d.ts"],
+                () => emptyArray
+            );
         });
 
         it("should fail when two files used in program differ only in casing (tripleslash references)", () => {
@@ -588,7 +599,25 @@ export = C;
                 "/a/b/c.ts": `/// <reference path="D.ts"/>`,
                 "/a/b/d.ts": "var x"
             });
-            test(files, { module: ModuleKind.AMD, forceConsistentCasingInFileNames: true }, "/a/b", /*useCaseSensitiveFileNames*/ false, ["c.ts", "d.ts"], [1149]);
+            test(
+                files,
+                { module: ModuleKind.AMD, forceConsistentCasingInFileNames: true },
+                "/a/b",
+                /*useCaseSensitiveFileNames*/ false,
+                ["c.ts", "d.ts"],
+                program => [{
+                    ...tscWatch.getDiagnosticOfFileFromProgram(
+                        program,
+                        "c.ts",
+                        `/// <reference path="D.ts"/>`.indexOf(`D.ts`),
+                        "D.ts".length,
+                        Diagnostics.Already_included_file_name_0_differs_from_file_name_1_only_in_casing,
+                        "D.ts",
+                        "d.ts",
+                    ),
+                    reportsUnnecessary: undefined
+                }]
+            );
         });
 
         it("should fail when two files used in program differ only in casing (imports)", () => {
@@ -596,7 +625,25 @@ export = C;
                 "/a/b/c.ts": `import {x} from "D"`,
                 "/a/b/d.ts": "export var x"
             });
-            test(files, { module: ModuleKind.AMD, forceConsistentCasingInFileNames: true }, "/a/b", /*useCaseSensitiveFileNames*/ false, ["c.ts", "d.ts"], [1149]);
+            test(
+                files,
+                { module: ModuleKind.AMD, forceConsistentCasingInFileNames: true },
+                "/a/b",
+                /*useCaseSensitiveFileNames*/ false,
+                ["c.ts", "d.ts"],
+                program => [{
+                    ...tscWatch.getDiagnosticOfFileFromProgram(
+                        program,
+                        "c.ts",
+                        `import {x} from "D"`.indexOf(`"D"`),
+                        `"D"`.length,
+                        Diagnostics.Already_included_file_name_0_differs_from_file_name_1_only_in_casing,
+                        "/a/b/D.ts",
+                        "d.ts",
+                    ),
+                    reportsUnnecessary: undefined
+                }]
+            );
         });
 
         it("should fail when two files used in program differ only in casing (imports, relative module names)", () => {
@@ -604,7 +651,25 @@ export = C;
                 "moduleA.ts": `import {x} from "./ModuleB"`,
                 "moduleB.ts": "export var x"
             });
-            test(files, { module: ModuleKind.CommonJS, forceConsistentCasingInFileNames: true }, "", /*useCaseSensitiveFileNames*/ false, ["moduleA.ts", "moduleB.ts"], [1149]);
+            test(
+                files,
+                { module: ModuleKind.CommonJS, forceConsistentCasingInFileNames: true },
+                "",
+                /*useCaseSensitiveFileNames*/ false,
+                ["moduleA.ts", "moduleB.ts"],
+                program => [{
+                    ...tscWatch.getDiagnosticOfFileFromProgram(
+                        program,
+                        "moduleA.ts",
+                        `import {x} from "./ModuleB"`.indexOf(`"./ModuleB"`),
+                        `"./ModuleB"`.length,
+                        Diagnostics.Already_included_file_name_0_differs_from_file_name_1_only_in_casing,
+                        "ModuleB.ts",
+                        "moduleB.ts",
+                    ),
+                    reportsUnnecessary: undefined
+                }]
+            );
         });
 
         it("should fail when two files exist on disk that differs only in casing", () => {
@@ -613,7 +678,25 @@ export = C;
                 "/a/b/D.ts": "export var x",
                 "/a/b/d.ts": "export var y"
             });
-            test(files, { module: ModuleKind.AMD }, "/a/b", /*useCaseSensitiveFileNames*/ true, ["c.ts", "d.ts"], [1149]);
+            test(
+                files,
+                { module: ModuleKind.AMD },
+                "/a/b",
+                /*useCaseSensitiveFileNames*/ true,
+                ["c.ts", "d.ts"],
+                program => [{
+                    ...tscWatch.getDiagnosticOfFileFromProgram(
+                        program,
+                        "c.ts",
+                        `import {x} from "D"`.indexOf(`"D"`),
+                        `"D"`.length,
+                        Diagnostics.Already_included_file_name_0_differs_from_file_name_1_only_in_casing,
+                        "/a/b/D.ts",
+                        "d.ts",
+                    ),
+                    reportsUnnecessary: undefined
+                }]
+            );
         });
 
         it("should fail when module name in 'require' calls has inconsistent casing", () => {
@@ -622,7 +705,39 @@ export = C;
                 "moduleB.ts": `import a = require("./moduleC")`,
                 "moduleC.ts": "export var x"
             });
-            test(files, { module: ModuleKind.CommonJS, forceConsistentCasingInFileNames: true }, "", /*useCaseSensitiveFileNames*/ false, ["moduleA.ts", "moduleB.ts", "moduleC.ts"], [1149, 1149]);
+            test(
+                files,
+                { module: ModuleKind.CommonJS, forceConsistentCasingInFileNames: true },
+                "",
+                /*useCaseSensitiveFileNames*/ false,
+                ["moduleA.ts", "moduleB.ts", "moduleC.ts"],
+                program => [
+                    {
+                        ...tscWatch.getDiagnosticOfFileFromProgram(
+                            program,
+                            "moduleA.ts",
+                            `import a = require("./ModuleC")`.indexOf(`"./ModuleC"`),
+                            `"./ModuleC"`.length,
+                            Diagnostics.Already_included_file_name_0_differs_from_file_name_1_only_in_casing,
+                            "ModuleC.ts",
+                            "moduleC.ts",
+                        ),
+                        reportsUnnecessary: undefined
+                    },
+                    {
+                        ...tscWatch.getDiagnosticOfFileFromProgram(
+                            program,
+                            "moduleB.ts",
+                            `import a = require("./moduleC")`.indexOf(`"./moduleC"`),
+                            `"./moduleC"`.length,
+                            Diagnostics.File_name_0_differs_from_already_included_file_name_1_only_in_casing,
+                            "moduleC.ts",
+                            "ModuleC.ts"
+                        ),
+                        reportsUnnecessary: undefined
+                    }
+                ]
+            );
         });
 
         it("should fail when module names in 'require' calls has inconsistent casing and current directory has uppercase chars", () => {
@@ -635,7 +750,25 @@ import a = require("./moduleA");
 import b = require("./moduleB");
                 `
             });
-            test(files, { module: ModuleKind.CommonJS, forceConsistentCasingInFileNames: true }, "/a/B/c", /*useCaseSensitiveFileNames*/ false, ["moduleD.ts"], [1149]);
+            test(
+                files,
+                { module: ModuleKind.CommonJS, forceConsistentCasingInFileNames: true },
+                "/a/B/c",
+                /*useCaseSensitiveFileNames*/ false,
+                ["moduleD.ts"],
+                program => [{
+                    ...tscWatch.getDiagnosticOfFileFromProgram(
+                        program,
+                        "moduleB.ts",
+                        `import a = require("./moduleC")`.indexOf(`"./moduleC"`),
+                        `"./moduleC"`.length,
+                        Diagnostics.File_name_0_differs_from_already_included_file_name_1_only_in_casing,
+                        "/a/B/c/moduleC.ts",
+                        "/a/B/c/ModuleC.ts"
+                    ),
+                    reportsUnnecessary: undefined
+                }]
+            );
         });
         it("should not fail when module names in 'require' calls has consistent casing and current directory has uppercase chars", () => {
             const files = createMapFromTemplate({
@@ -647,7 +780,14 @@ import a = require("./moduleA");
 import b = require("./moduleB");
                 `
             });
-            test(files, { module: ModuleKind.CommonJS, forceConsistentCasingInFileNames: true }, "/a/B/c", /*useCaseSensitiveFileNames*/ false, ["moduleD.ts"], []);
+            test(
+                files,
+                { module: ModuleKind.CommonJS, forceConsistentCasingInFileNames: true },
+                "/a/B/c",
+                /*useCaseSensitiveFileNames*/ false,
+                ["moduleD.ts"],
+                () => emptyArray
+            );
         });
 
         it("should succeed when the two files in program differ only in drive letter in their names", () => {
@@ -662,7 +802,7 @@ import b = require("./moduleB");
                 "d:/someFolder",
                 /*useCaseSensitiveFileNames*/ false,
                 ["d:/someFolder/moduleA.ts", "d:/someFolder/moduleB.ts"],
-                []
+                () => emptyArray
             );
         });
     });
