@@ -1,4 +1,6 @@
 namespace ts {
+    const _chai: typeof import("chai") = require("chai");
+    const expect: typeof _chai.expect = _chai.expect;
     describe("unittests:: services:: languageService", () => {
         const files: {[index: string]: string} = {
             "foo.ts": `import Vue from "./vue";
