@@ -1075,118 +1075,6 @@ namespace ts.projectSystem {
             assert.equal(options.outDir, "C:/a/b", "");
         });
 
-        it("dynamic file without external project", () => {
-            const file: File = {
-                path: "^walkThroughSnippet:/Users/UserName/projects/someProject/out/someFile#1.js",
-                content: "var x = 10;"
-            };
-            const host = createServerHost([libFile], { useCaseSensitiveFileNames: true });
-            const projectService = createProjectService(host);
-            projectService.setCompilerOptionsForInferredProjects({
-                module: ModuleKind.CommonJS,
-                allowJs: true,
-                allowSyntheticDefaultImports: true,
-                allowNonTsExtensions: true
-            });
-            projectService.openClientFile(file.path, "var x = 10;");
-
-            projectService.checkNumberOfProjects({ inferredProjects: 1 });
-            const project = projectService.inferredProjects[0];
-            checkProjectRootFiles(project, [file.path]);
-            checkProjectActualFiles(project, [file.path, libFile.path]);
-
-            assert.strictEqual(projectService.ensureDefaultProjectForFile(server.toNormalizedPath(file.path)), project);
-            const indexOfX = file.content.indexOf("x");
-            assert.deepEqual(project.getLanguageService(/*ensureSynchronized*/ true).getQuickInfoAtPosition(file.path, indexOfX), {
-                kind: ScriptElementKind.variableElement,
-                kindModifiers: "",
-                textSpan: { start: indexOfX, length: 1 },
-                displayParts: [
-                    { text: "var", kind: "keyword" },
-                    { text: " ", kind: "space" },
-                    { text: "x", kind: "localName" },
-                    { text: ":", kind: "punctuation" },
-                    { text: " ", kind: "space" },
-                    { text: "number", kind: "keyword" }
-                ],
-                documentation: [],
-                tags: undefined,
-            });
-        });
-
-        it("dynamic file with reference paths without external project", () => {
-            const file: File = {
-                path: "^walkThroughSnippet:/Users/UserName/projects/someProject/out/someFile#1.js",
-                content: `/// <reference path="../../../../../../typings/@epic/Core.d.ts" />
-/// <reference path="../../../../../../typings/@epic/Shell.d.ts" />
-var x = 10;`
-            };
-            const host = createServerHost([libFile]);
-            const projectService = createProjectService(host);
-            projectService.openClientFile(file.path, file.content);
-
-            projectService.checkNumberOfProjects({ inferredProjects: 1 });
-            const project = projectService.inferredProjects[0];
-            checkProjectRootFiles(project, [file.path]);
-            checkProjectActualFiles(project, [file.path, libFile.path]);
-        });
-
-        describe("dynamic file with projectRootPath", () => {
-            const file: File = {
-                path: "^walkThroughSnippet:/Users/UserName/projects/someProject/out/someFile#1.js",
-                content: "var x = 10;"
-            };
-            const configFile: File = {
-                path: `${projectRoot}/tsconfig.json`,
-                content: "{}"
-            };
-            const configProjectFile: File = {
-                path: `${projectRoot}/a.ts`,
-                content: "let y = 10;"
-            };
-            it("with useInferredProjectPerProjectRoot", () => {
-                const host = createServerHost([libFile, configFile, configProjectFile], { useCaseSensitiveFileNames: true });
-                const session = createSession(host, { useInferredProjectPerProjectRoot: true });
-                openFilesForSession([{ file: file.path, projectRootPath: projectRoot }], session);
-
-                const projectService = session.getProjectService();
-                checkNumberOfProjects(projectService, { inferredProjects: 1 });
-                checkProjectActualFiles(projectService.inferredProjects[0], [file.path, libFile.path]);
-
-                session.executeCommandSeq<protocol.OutliningSpansRequest>({
-                    command: protocol.CommandTypes.GetOutliningSpans,
-                    arguments: {
-                        file: file.path
-                    }
-                });
-
-                // Without project root
-                const file2Path = file.path.replace("#1", "#2");
-                projectService.openClientFile(file2Path, file.content);
-                checkNumberOfProjects(projectService, { inferredProjects: 2 });
-                checkProjectActualFiles(projectService.inferredProjects[0], [file.path, libFile.path]);
-                checkProjectActualFiles(projectService.inferredProjects[1], [file2Path, libFile.path]);
-            });
-
-            it("fails when useInferredProjectPerProjectRoot is false", () => {
-                const host = createServerHost([libFile, configFile, configProjectFile], { useCaseSensitiveFileNames: true });
-                const projectService = createProjectService(host);
-                try {
-                    projectService.openClientFile(file.path, file.content, /*scriptKind*/ undefined, projectRoot);
-                }
-                catch (e) {
-                    assert.strictEqual(
-                        e.message.replace(/\r?\n/, "\n"),
-                        `Debug Failure. False expression: \nVerbose Debug Information: {"fileName":"^walkThroughSnippet:/Users/UserName/projects/someProject/out/someFile#1.js","currentDirectory":"/user/username/projects/myproject","hostCurrentDirectory":"/","openKeys":[]}\nDynamic files must always be opened with service's current directory or service should support inferred project per projectRootPath.`
-                    );
-                }
-                const file2Path = file.path.replace("#1", "#2");
-                projectService.openClientFile(file2Path, file.content);
-                projectService.checkNumberOfProjects({ inferredProjects: 1 });
-                checkProjectActualFiles(projectService.inferredProjects[0], [file2Path, libFile.path]);
-            });
-        });
-
         it("files opened, closed affecting multiple projects", () => {
             const file: File = {
                 path: "/a/b/projects/config/file.ts",
@@ -1266,15 +1154,15 @@ var x = 10;`
 
         it("requests are done on file on pendingReload but has svc for previous version", () => {
             const file1: File = {
-                path: `${projectRoot}/src/file1.ts`,
+                path: `${tscWatch.projectRoot}/src/file1.ts`,
                 content: `import { y } from "./file2"; let x = 10;`
             };
             const file2: File = {
-                path: `${projectRoot}/src/file2.ts`,
+                path: `${tscWatch.projectRoot}/src/file2.ts`,
                 content: "export let y = 10;"
             };
             const config: File = {
-                path: `${projectRoot}/tsconfig.json`,
+                path: `${tscWatch.projectRoot}/tsconfig.json`,
                 content: "{}"
             };
             const files = [file1, file2, libFile, config];
@@ -1365,18 +1253,18 @@ var x = 10;`
 
         it("Orphan source files are handled correctly on watch trigger", () => {
             const file1: File = {
-                path: `${projectRoot}/src/file1.ts`,
+                path: `${tscWatch.projectRoot}/src/file1.ts`,
                 content: `export let x = 10;`
             };
             const file2: File = {
-                path: `${projectRoot}/src/file2.ts`,
+                path: `${tscWatch.projectRoot}/src/file2.ts`,
                 content: "export let y = 10;"
             };
             const configContent1 = JSON.stringify({
                 files: ["src/file1.ts", "src/file2.ts"]
             });
             const config: File = {
-                path: `${projectRoot}/tsconfig.json`,
+                path: `${tscWatch.projectRoot}/tsconfig.json`,
                 content: configContent1
             };
             const files = [file1, file2, libFile, config];
@@ -1428,6 +1316,176 @@ var x = 10;`
             host.checkTimeoutQueueLength(0);
         });
 
+        it("synchronizeProjectList provides redirect info when requested", () => {
+            const projectRootPath = "/users/username/projects/project";
+            const fileA: File = {
+                path: `${projectRootPath}/A/a.ts`,
+                content: "export const foo: string = 5;"
+            };
+            const configA: File = {
+                path: `${projectRootPath}/A/tsconfig.json`,
+                content: `{
+  "compilerOptions": {
+    "composite": true,
+    "declaration": true
+  }
+}`
+            };
+            const fileB: File = {
+                path: `${projectRootPath}/B/b.ts`,
+                content: "import { foo } from \"../A/a\"; console.log(foo);"
+            };
+            const configB: File = {
+                path: `${projectRootPath}/B/tsconfig.json`,
+                content: `{
+  "compilerOptions": {
+    "composite": true,
+    "declaration": true
+  },
+  "references": [
+    { "path": "../A" }
+  ]
+}`
+            };
+            const files = [fileA, fileB, configA, configB, libFile];
+            const host = createServerHost(files);
+            const projectService = createProjectService(host);
+            projectService.openClientFile(fileA.path);
+            projectService.openClientFile(fileB.path);
+            const knownProjects = projectService.synchronizeProjectList([], /*includeProjectReferenceRedirectInfo*/ true);
+            assert.deepEqual(knownProjects[0].files, [
+                {
+                    fileName: libFile.path,
+                    isSourceOfProjectReferenceRedirect: false
+                },
+                {
+                    fileName: fileA.path,
+                    isSourceOfProjectReferenceRedirect: false
+                },
+                {
+                    fileName: configA.path,
+                    isSourceOfProjectReferenceRedirect: false
+                }
+            ]);
+            assert.deepEqual(knownProjects[1].files, [
+                {
+                    fileName: libFile.path,
+                    isSourceOfProjectReferenceRedirect: false
+                },
+                {
+                    fileName: fileA.path,
+                    isSourceOfProjectReferenceRedirect: true,
+                },
+                {
+                    fileName: fileB.path,
+                    isSourceOfProjectReferenceRedirect: false,
+                },
+                {
+                    fileName: configB.path,
+                    isSourceOfProjectReferenceRedirect: false
+                }
+            ]);
+        });
+
+        it("synchronizeProjectList provides updates to redirect info when requested", () => {
+            const projectRootPath = "/users/username/projects/project";
+            const fileA: File = {
+                path: `${projectRootPath}/A/a.ts`,
+                content: "export const foo: string = 5;"
+            };
+            const configA: File = {
+                path: `${projectRootPath}/A/tsconfig.json`,
+                content: `{
+  "compilerOptions": {
+    "composite": true,
+    "declaration": true
+  }
+}`
+            };
+            const fileB: File = {
+                path: `${projectRootPath}/B/b.ts`,
+                content: "import { foo } from \"../B/b2\"; console.log(foo);"
+            };
+            const fileB2: File = {
+                path: `${projectRootPath}/B/b2.ts`,
+                content: "export const foo: string = 5;"
+            };
+            const configB: File = {
+                path: `${projectRootPath}/B/tsconfig.json`,
+                content: `{
+  "compilerOptions": {
+    "composite": true,
+    "declaration": true
+  },
+  "references": [
+    { "path": "../A" }
+  ]
+}`
+            };
+            const files = [fileA, fileB, fileB2, configA, configB, libFile];
+            const host = createServerHost(files);
+            const projectService = createProjectService(host);
+            projectService.openClientFile(fileA.path);
+            projectService.openClientFile(fileB.path);
+            const knownProjects = projectService.synchronizeProjectList([], /*includeProjectReferenceRedirectInfo*/ true);
+            assert.deepEqual(knownProjects[0].files, [
+                {
+                    fileName: libFile.path,
+                    isSourceOfProjectReferenceRedirect: false
+                },
+                {
+                    fileName: fileA.path,
+                    isSourceOfProjectReferenceRedirect: false
+                },
+                {
+                    fileName: configA.path,
+                    isSourceOfProjectReferenceRedirect: false
+                }
+            ]);
+            assert.deepEqual(knownProjects[1].files, [
+                {
+                    fileName: libFile.path,
+                    isSourceOfProjectReferenceRedirect: false
+                },
+                {
+                    fileName: fileB2.path,
+                    isSourceOfProjectReferenceRedirect: false,
+                },
+                {
+                    fileName: fileB.path,
+                    isSourceOfProjectReferenceRedirect: false,
+                },
+                {
+                    fileName: configB.path,
+                    isSourceOfProjectReferenceRedirect: false
+                }
+            ]);
+
+            host.modifyFile(configA.path, `{
+  "compilerOptions": {
+    "composite": true,
+    "declaration": true
+  },
+  "include": [
+      "**/*",
+      "../B/b2.ts"
+  ]
+}`);
+            const newKnownProjects = projectService.synchronizeProjectList(knownProjects.map(proj => proj.info!), /*includeProjectReferenceRedirectInfo*/ true);
+            assert.deepEqual(newKnownProjects[0].changes?.added, [
+                {
+                    fileName: fileB2.path,
+                    isSourceOfProjectReferenceRedirect: false
+                }
+            ]);
+            assert.deepEqual(newKnownProjects[1].changes?.updatedRedirects, [
+                {
+                    fileName: fileB2.path,
+                    isSourceOfProjectReferenceRedirect: true
+                }
+            ]);
+        });
+
         it("handles delayed directory watch invoke on file creation", () => {
             const projectRootPath = "/users/username/projects/project";
             const fileB: File = {
@@ -1505,7 +1563,7 @@ var x = 10;`
                 host,
                 expected: [
                     { file: fileB, syntax: [], semantic: [], suggestion: [] },
-                    { file: fileSubA },
+                    { file: fileSubA, syntax: [], semantic: [], suggestion: [] },
                 ],
                 existingTimeouts: 2,
                 onErrEvent: () => assert.isFalse(hasErrorMsg())
