@@ -1,6 +1,6 @@
-const expect: typeof _chai.expect = _chai.expect;
-
 namespace ts.server {
+    const _chai: typeof import("chai") = require("chai");
+    const expect: typeof _chai.expect = _chai.expect;
     let lastWrittenToHost: string;
     const noopFileWatcher: FileWatcher = { close: noop };
     const mockHost: ServerHost = {
@@ -100,7 +100,8 @@ namespace ts.server {
                     seq: 0,
                     message: "Unrecognized JSON command: foobar",
                     request_seq: 0,
-                    success: false
+                    success: false,
+                    performanceData: undefined,
                 };
                 expect(lastSent).to.deep.equal(expected);
             });
@@ -126,7 +127,8 @@ namespace ts.server {
                     success: true,
                     request_seq: 0,
                     seq: 0,
-                    body: undefined
+                    body: undefined,
+                    performanceData: undefined,
                 });
             });
             it("should handle literal types in request", () => {
@@ -179,7 +181,9 @@ namespace ts.server {
                     type: "request"
                 };
 
-                const expected: protocol.StatusResponseBody = { version };
+                const expected: protocol.StatusResponseBody = {
+                    version: ts.version, // eslint-disable-line @typescript-eslint/no-unnecessary-qualifier
+                };
                 assert.deepEqual(session.executeCommand(req).response, expected);
             });
         });
@@ -265,6 +269,9 @@ namespace ts.server {
                 CommandNames.GetEditsForFileRename,
                 CommandNames.GetEditsForFileRenameFull,
                 CommandNames.SelectionRange,
+                CommandNames.PrepareCallHierarchy,
+                CommandNames.ProvideCallHierarchyIncomingCalls,
+                CommandNames.ProvideCallHierarchyOutgoingCalls,
             ];
 
             it("should not throw when commands are executed with invalid arguments", () => {
@@ -321,7 +328,8 @@ namespace ts.server {
                     success: true,
                     request_seq: 0,
                     seq: 0,
-                    body: undefined
+                    body: undefined,
+                    performanceData: undefined,
                 });
             });
         });
@@ -411,7 +419,8 @@ namespace ts.server {
                     type: "response",
                     command,
                     body,
-                    success: true
+                    success: true,
+                    performanceData: undefined,
                 });
             });
         });
@@ -530,7 +539,8 @@ namespace ts.server {
                 type: "response",
                 command,
                 body,
-                success: true
+                success: true,
+                performanceData: undefined,
             });
         });
         it("can add and respond to new protocol handlers", () => {
