@@ -8,7 +8,6 @@ function*bar() {
 //// [FunctionDeclaration7_es6.js]
 function* bar() {
     // 'yield' here is an identifier, and not a yield expression.
-    function* foo(a) {
-        if (a === void 0) { a = yield; }
+    function* foo(a = yield) {
     }
 }
