@@ -4,9 +4,6 @@ class C {
 }
 
 //// [MemberFunctionDeclaration7_es6.js]
-var C = (function () {
-    function C() {
-    }
-    C.prototype.foo = function* () { };
-    return C;
-}());
+class C {
+    *foo() { }
+}
