@@ -13,7 +13,7 @@ export = Foo;
 define("NamedModule", ["require", "exports"], function (require, exports) {
     "use strict";
     ///<amd-module name='NamedModule'/>
-    var Foo = (function () {
+    var Foo = /** @class */ (function () {
         function Foo() {
             this.x = 5;
         }
