@@ -6,7 +6,7 @@ var c = new C(() => { return asdf; } ) // should error
 
 
 //// [arrowFunctionInConstructorArgument1.js]
-var C = (function () {
+var C = /** @class */ (function () {
     function C(x) {
     }
     return C;
