@@ -11,4 +11,4 @@ var d = () => ((<Error>({ name: "foo", message: "bar" })));
 var a = function () { return ({ name: "foo", message: "bar" }); };
 var b = function () { return ({ name: "foo", message: "bar" }); };
 var c = function () { return ({ name: "foo", message: "bar" }); };
-var d = function () { return (({ name: "foo", message: "bar" })); };
+var d = function () { return ({ name: "foo", message: "bar" }); };
