@@ -45,12 +45,12 @@ a2 = t;
 //// [assignmentCompatWithObjectMembers2.js]
 // members N and M of types S and T have the same name, same accessibility, same optionality, and N is assignable M
 // additional optional properties do not cause errors
-var S = (function () {
+var S = /** @class */ (function () {
     function S() {
     }
     return S;
 }());
-var T = (function () {
+var T = /** @class */ (function () {
     function T() {
     }
     return T;
