@@ -3,6 +3,7 @@ var foo = async (a = await => await): Promise<void> => {
 }
 
 //// [asyncArrowFunction9_es2017.js]
-var foo = async(a = await => await), Promise = ;
+var foo = async(a = await => await), Promise;
+;
 {
 }
