@@ -2,4 +2,5 @@
 var v = async function await(): Promise<void> { }
 
 //// [asyncFunctionDeclaration12_es2017.js]
-var v = async function () { }, await = () => { };
+var v = async function () { }, await;
+() => { };
