@@ -10,7 +10,7 @@ async function f(): X.MyPromise<void> {
 //// [asyncQualifiedReturnType_es5.js]
 var X;
 (function (X) {
-    var MyPromise = (function (_super) {
+    var MyPromise = /** @class */ (function (_super) {
         __extends(MyPromise, _super);
         function MyPromise() {
             return _super !== null && _super.apply(this, arguments) || this;
