@@ -5,7 +5,7 @@ class C {
 }
 
 //// [asyncSetter_es5.js]
-var C = (function () {
+var C = /** @class */ (function () {
     function C() {
     }
     Object.defineProperty(C.prototype, "foo", {
