@@ -9,7 +9,7 @@ enum c4 { One } // error
 
 //// [augmentedTypesClass.js]
 //// class then var
-var c1 = (function () {
+var c1 = /** @class */ (function () {
     function c1() {
     }
     c1.prototype.foo = function () { };
@@ -17,7 +17,7 @@ var c1 = (function () {
 }());
 var c1 = 1; // error
 //// class then enum
-var c4 = (function () {
+var c4 = /** @class */ (function () {
     function c4() {
     }
     c4.prototype.foo = function () { };
