@@ -6,7 +6,7 @@ var c2 = () => { }
 
 //// [augmentedTypesClass2a.js]
 //// class then function
-var c2 = (function () {
+var c2 = /** @class */ (function () {
     function c2() {
     }
     c2.prototype.foo = function () { };
