@@ -46,7 +46,7 @@ var m4c;
 })(m4c || (m4c = {}));
 var m4d;
 (function (m4d) {
-    var C = (function () {
+    var C = /** @class */ (function () {
         function C() {
         }
         C.prototype.foo = function () { };
