@@ -27,7 +27,7 @@ var y = f(); // error void fn
 var why = f(); // error void fn
 var w;
 w = f(); // error void fn
-var C = (function () {
+var C = /** @class */ (function () {
     function C() {
     }
     C.prototype.g = function () {
