@@ -1,4 +1,6 @@
 //// [capturedLetConstInLoop1.ts]
+declare function use(x: any): any;
+
 //==== let
 for (let x in {}) {
     (function() { return x});
@@ -56,6 +58,19 @@ for (let y = 0; y < 1; ++y) {
     (() => x + y);
 }
 
+for (let y = (use(() => y), 0); y < 1; ++y) {
+}
+
+for (let y = 0; use(() => y), y < 1; ++y) {
+}
+
+for (let y = 0; y < 1; use(() => y), ++y) {
+}
+
+for (let y = (use(() => y), 0); use(() => y), y < 1; use(() => y), ++y) {
+    use(() => y);
+}
+
 //=========const
 for (const x in {}) {
     (function() { return x});
@@ -202,93 +217,145 @@ var _loop_10 = function (y) {
 for (var y = 0; y < 1; ++y) {
     _loop_10(y);
 }
-var _loop_11 = function (x) {
+var _loop_init_1 = function () {
+    var y = (use(function () { return y; }), 0);
+    out_y_1 = y;
+};
+var out_y_1;
+_loop_init_1();
+for (var y = out_y_1; y < 1; ++y) {
+}
+var _loop_11 = function (y) {
+    if (inc_1)
+        ++y;
+    else
+        inc_1 = true;
+    if (!(use(function () { return y; }), y < 1))
+        return "break";
+};
+var inc_1 = false;
+for (var y = 0;;) {
+    var state_1 = _loop_11(y);
+    if (state_1 === "break")
+        break;
+}
+var _loop_12 = function (y) {
+    if (inc_2)
+        use(function () { return y; }), ++y;
+    else
+        inc_2 = true;
+};
+var inc_2 = false;
+for (var y = 0; y < 1;) {
+    _loop_12(y);
+}
+var _loop_init_2 = function () {
+    var y = (use(function () { return y; }), 0);
+    out_y_2 = y;
+};
+var _loop_13 = function (y) {
+    if (inc_3)
+        use(function () { return y; }), ++y;
+    else
+        inc_3 = true;
+    if (!(use(function () { return y; }), y < 1))
+        return out_y_2 = y, "break";
+    use(function () { return y; });
+};
+var out_y_2, inc_3 = false;
+_loop_init_2();
+for (var y = out_y_2;;) {
+    var state_2 = _loop_13(y);
+    if (state_2 === "break")
+        break;
+}
+var _loop_14 = function (x) {
     (function () { return x; });
     (function () { return x; });
 };
 //=========const
 for (var x in {}) {
-    _loop_11(x);
+    _loop_14(x);
 }
-var _loop_12 = function (x) {
+var _loop_15 = function (x) {
     (function () { return x; });
     (function () { return x; });
 };
 for (var _b = 0, _c = []; _b < _c.length; _b++) {
     var x = _c[_b];
-    _loop_12(x);
+    _loop_15(x);
 }
-var _loop_13 = function (x) {
+var _loop_16 = function (x) {
     (function () { return x; });
     (function () { return x; });
 };
 for (var x = 0; x < 1;) {
-    _loop_13(x);
+    _loop_16(x);
 }
-var _loop_14 = function () {
+var _loop_17 = function () {
     var x = 1;
     (function () { return x; });
     (function () { return x; });
 };
 while (1 === 1) {
-    _loop_14();
+    _loop_17();
 }
-var _loop_15 = function () {
+var _loop_18 = function () {
     var x = 1;
     (function () { return x; });
     (function () { return x; });
 };
 do {
-    _loop_15();
+    _loop_18();
 } while (1 === 1);
-var _loop_16 = function (y) {
+var _loop_19 = function (y) {
     var x = 1;
     (function () { return x; });
     (function () { return x; });
 };
 for (var y = 0; y < 1;) {
-    _loop_16(y);
+    _loop_19(y);
 }
-var _loop_17 = function (x, y) {
+var _loop_20 = function (x, y) {
     (function () { return x + y; });
     (function () { return x + y; });
 };
 for (var x = 0, y = 1; x < 1;) {
-    _loop_17(x, y);
+    _loop_20(x, y);
 }
-var _loop_18 = function () {
+var _loop_21 = function () {
     var x = 1, y = 1;
     (function () { return x + y; });
     (function () { return x + y; });
 };
 while (1 === 1) {
-    _loop_18();
+    _loop_21();
 }
-var _loop_19 = function () {
+var _loop_22 = function () {
     var x = 1, y = 1;
     (function () { return x + y; });
     (function () { return x + y; });
 };
 do {
-    _loop_19();
+    _loop_22();
 } while (1 === 1);
-var _loop_20 = function (y) {
+var _loop_23 = function (y) {
     var x = 1;
     (function () { return x + y; });
     (function () { return x + y; });
 };
 for (var y = 0; y < 1;) {
-    _loop_20(y);
+    _loop_23(y);
 }
-var _loop_21 = function (sx) {
+var _loop_24 = function (sx) {
     (function () { return sobj[sx]; });
 };
 for (var sx in sobj) {
-    _loop_21(sx);
+    _loop_24(sx);
 }
-var _loop_22 = function (ix) {
+var _loop_25 = function (ix) {
     (function () { return iobj[ix]; });
 };
 for (var ix in iobj) {
-    _loop_22(ix);
+    _loop_25(ix);
 }
