@@ -1,20 +1,37 @@
 //// [capturedParametersInInitializers2.ts]
-function foo(y = class {static c = x}, x = 1) {
+function foo(
+    y = class {
+        static c = x;
+        get [x]() {return x;}
+        constructor() { x; }
+        [z]() { return z; }
+    },
+    x = 1,
+    z = 2
+) {
     y.c
 }
 function foo2(y = class {[x] = x}, x = 1) {
 }
 
 //// [capturedParametersInInitializers2.js]
-function foo(y, x) {
+function foo(y, x, z) {
     if (y === void 0) { y = (_a = /** @class */ (function () {
             function class_1() {
+                x;
             }
+            Object.defineProperty(class_1.prototype, x, {
+                get: function () { return x; },
+                enumerable: true,
+                configurable: true
+            });
+            class_1.prototype[z] = function () { return z; };
             return class_1;
         }()),
         _a.c = x,
         _a); }
     if (x === void 0) { x = 1; }
+    if (z === void 0) { z = 2; }
     var _a;
     y.c;
 }
