@@ -11,17 +11,17 @@ function f() {
 
 //// [classDeclarationBlockScoping2.js]
 function f() {
-    var C = (function () {
+    var C = /** @class */ (function () {
         function C() {
         }
         return C;
     }());
     var c1 = C;
     {
-        var C_1 = (function () {
-            function C_1() {
+        var C_1 = /** @class */ (function () {
+            function C() {
             }
-            return C_1;
+            return C;
         }());
         var c2 = C_1;
     }
