@@ -9,7 +9,7 @@ let x = class B implements A {
 };
 
 //// [classExpressions.js]
-var x = (function () {
+var x = /** @class */ (function () {
     function B() {
         this.func = function () {
         };
