@@ -15,14 +15,14 @@ class D2 implements I {
 } 
 
 //// [classExtendsInterfaceThatExtendsClassWithPrivates1.js]
-var C = (function () {
+var C = /** @class */ (function () {
     function C() {
         this.x = 1;
     }
     C.prototype.foo = function (x) { return x; };
     return C;
 }());
-var D2 = (function () {
+var D2 = /** @class */ (function () {
     function D2() {
         this.x = 3;
     }
