@@ -27,7 +27,7 @@ module M {
 var M;
 (function (M_1) {
     M_1.x = 3;
-    var c = (function () {
+    var c = /** @class */ (function () {
         function c(M, p) {
             if (p === void 0) { p = M_1.x; }
         }
@@ -35,7 +35,7 @@ var M;
     }());
 })(M || (M = {}));
 (function (M_2) {
-    var d = (function () {
+    var d = /** @class */ (function () {
         function d(M, p) {
             if (p === void 0) { p = M_2.x; }
             this.M = M;
@@ -44,7 +44,7 @@ var M;
     }());
 })(M || (M = {}));
 (function (M_3) {
-    var d2 = (function () {
+    var d2 = /** @class */ (function () {
         function d2() {
             var M = 10;
             var p = M_3.x;
