@@ -4,6 +4,6 @@ var f = () => this;
 _this = 10; // Error
 
 //// [collisionThisExpressionAndAmbientVarInGlobal.js]
-var _this = this;
-var f = function () { return _this; };
+var _this_1 = this;
+var f = function () { return _this_1; };
 _this = 10; // Error
