@@ -22,11 +22,11 @@ class class2 {
 //// [collisionThisExpressionAndLocalVarInProperty.js]
 var class1 = /** @class */ (function () {
     function class1() {
-        var _this = this;
+        var _this_1 = this;
         this.prop1 = {
             doStuff: function (callback) { return function () {
                 var _this = 2;
-                return callback(_this);
+                return callback(_this_1);
             }; }
         };
     }
@@ -34,10 +34,10 @@ var class1 = /** @class */ (function () {
 }());
 var class2 = /** @class */ (function () {
     function class2() {
-        var _this = this;
+        var _this_1 = this;
         this.prop1 = {
             doStuff: function (callback) { return function () {
-                return callback(_this);
+                return callback(_this_1);
             }; }
         };
         var _this = 2;
