@@ -3,6 +3,6 @@ var _this = 1;
 var f = () => this;
 
 //// [collisionThisExpressionAndVarInGlobal.js]
-var _this = this;
+var _this_1 = this;
 var _this = 1;
-var f = function () { return _this; };
+var f = function () { return _this_1; };
