@@ -19,7 +19,7 @@ var M;
 
 //// [constDeclarations2.d.ts]
 declare module M {
-    const c1: boolean;
+    const c1 = false;
     const c2: number;
     const c3 = 0, c4: string, c5: any;
 }
