@@ -37,7 +37,7 @@ declare const enum G {
     A = 1,
     B = 2,
     C = 3,
-    D = 2,
+    D = 2
 }
 declare var z: typeof G;
 declare var z1: any;
