@@ -1,5 +1,4 @@
 //// [constructableDecoratorOnClass01.ts]
-
 class CtorDtor {}
 
 @CtorDtor
@@ -15,16 +14,16 @@ var __decorate = (this && this.__decorate) || function (decorators, target, key,
     else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
     return c > 3 && r && Object.defineProperty(target, key, r), r;
 };
-var CtorDtor = (function () {
+var CtorDtor = /** @class */ (function () {
     function CtorDtor() {
     }
     return CtorDtor;
 }());
-var C = (function () {
+var C = /** @class */ (function () {
     function C() {
     }
+    C = __decorate([
+        CtorDtor
+    ], C);
     return C;
 }());
-C = __decorate([
-    CtorDtor
-], C);
