@@ -6,7 +6,7 @@ class foo {
 
 
 //// [constructorArgsErrors5.js]
-var foo = (function () {
+var foo = /** @class */ (function () {
     function foo(a) {
     }
     return foo;
