@@ -2,7 +2,7 @@
 class foo { public bar:{id:number;}[] = [{id:1}, {id:2, name:"foo"}]; }
 
 //// [contextualTyping12.js]
-var foo = (function () {
+var foo = /** @class */ (function () {
     function foo() {
         this.bar = [{ id: 1 }, { id: 2, name: "foo" }];
     }
