@@ -20,6 +20,6 @@ var x = e;
 declare enum e {
     a = 0,
     b = 1,
-    c = 2,
+    c = 2
 }
 declare var x: typeof e;
