@@ -58,7 +58,7 @@ declare module m1 {
     enum e {
         weekday = 0,
         weekend = 1,
-        holiday = 2,
+        holiday = 2
     }
 }
 declare var a: {
