@@ -14,5 +14,5 @@ function foo(_a) {
 
 
 //// [declarationEmitDestructuring3.d.ts]
-declare function bar([x, z, ...w]: any[]): void;
-declare function foo([x, ...y]?: (string | number | boolean)[]): void;
+declare function bar([x, z, ...w]: [any, any, ...any[]]): void;
+declare function foo([x, ...y]?: [number, string, boolean]): void;
