@@ -6,7 +6,7 @@ class C {
 }
 
 //// [decoratorOnClassConstructor1.js]
-var C = (function () {
+var C = /** @class */ (function () {
     function C() {
     }
     return C;
