@@ -15,11 +15,11 @@ var __decorate = (this && this.__decorate) || function (decorators, target, key,
 var __param = (this && this.__param) || function (paramIndex, decorator) {
     return function (target, key) { decorator(target, key, paramIndex); }
 };
-var C = (function () {
+var C = /** @class */ (function () {
     function C(public, p) {
     }
+    C = __decorate([
+        __param(1, dec)
+    ], C);
     return C;
 }());
-C = __decorate([
-    __param(1, dec)
-], C);
