@@ -12,11 +12,11 @@ var __decorate = (this && this.__decorate) || function (decorators, target, key,
     else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
     return c > 3 && r && Object.defineProperty(target, key, r), r;
 };
-var C = (function () {
+var C = /** @class */ (function () {
     function C() {
     }
+    __decorate([
+        dec
+    ], C.prototype, "prop", void 0);
     return C;
 }());
-__decorate([
-    dec
-], C.prototype, "prop", void 0);
