@@ -6,7 +6,7 @@ class C {
 }
 
 //// [defaultValueInConstructorOverload1.js]
-var C = (function () {
+var C = /** @class */ (function () {
     function C(x) {
         if (x === void 0) { x = ''; }
     }
