@@ -3,6 +3,7 @@ var x: "p" = "p"
 class A {
     a = this.y
     b
+    public c;
     ["computed"] = 13
     ;[x] = 14
     m() { }
@@ -11,8 +12,10 @@ class A {
     declare notEmitted;
 }
 class B {
+    public a;
 }
 class C extends B {
+    declare public a;
     z = this.ka
     constructor(public ka: number) {
         super()
@@ -27,6 +30,7 @@ class A {
     y;
     a = this.y;
     b;
+    c;
     ["computed"] = 13;
     [x] = 14;
     m() { }
@@ -36,6 +40,7 @@ class A {
     z = this.y;
 }
 class B {
+    a;
 }
 class C extends B {
     ka;
