@@ -66,6 +66,21 @@ class K extends J {
     r!: 4 | 5 // error, from class
 }
 
+// #35327
+class L {
+    a: any;
+    constructor(arg: any) {
+        this.a = arg;
+    }
+}
+class M extends L {
+    declare a: number;
+    constructor(arg: number) {
+        super(arg);
+        console.log(this.a);  // should be OK, M.a is ambient
+    }
+}
+
 
 //// [derivedUninitializedPropertyDeclaration.js]
 "use strict";
@@ -178,3 +193,19 @@ var K = /** @class */ (function (_super) {
     }
     return K;
 }(J));
+// #35327
+var L = /** @class */ (function () {
+    function L(arg) {
+        this.a = arg;
+    }
+    return L;
+}());
+var M = /** @class */ (function (_super) {
+    __extends(M, _super);
+    function M(arg) {
+        var _this = _super.call(this, arg) || this;
+        console.log(_this.a); // should be OK, M.a is ambient
+        return _this;
+    }
+    return M;
+}(L));
