@@ -9,7 +9,7 @@ class TestFile {
 }
 
 //// [detachedCommentAtStartOfFunctionBody1.js]
-var TestFile = (function () {
+var TestFile = /** @class */ (function () {
     function TestFile() {
     }
     TestFile.prototype.foo = function (message) {
