@@ -94,6 +94,55 @@ function f31(foo: Foo) {
     }
 }
 
+// Repro from #33448
+
+type a = {
+    type: 'a',
+    data: string
+}
+type b = {
+    type: 'b',
+    name: string
+}
+type c = {
+    type: 'c',
+    other: string
+}
+
+type abc = a | b | c;
+
+function f(problem: abc & (b | c)) {
+    if (problem.type === 'b') {
+        problem.name;
+    }
+    else {
+        problem.other;
+    }
+}
+
+type RuntimeValue =
+    | { type: 'number', value: number }
+    | { type: 'string', value: string }
+    | { type: 'boolean', value: boolean };
+
+function foo1(x: RuntimeValue & { type: 'number' }) {
+    if (x.type === 'number') {
+        x.value;  // number
+    }
+    else {
+        x.value;  // Error, x is never
+    }
+}
+
+function foo2(x: RuntimeValue & ({ type: 'number' } | { type: 'string' })) {
+    if (x.type === 'number') {
+        x.value;  // number
+    }
+    else {
+        x.value;  // string
+    }
+}
+
 
 //// [discriminatedUnionTypes2.js]
 "use strict";
@@ -164,3 +213,27 @@ function f31(foo) {
         foo;
     }
 }
+function f(problem) {
+    if (problem.type === 'b') {
+        problem.name;
+    }
+    else {
+        problem.other;
+    }
+}
+function foo1(x) {
+    if (x.type === 'number') {
+        x.value; // number
+    }
+    else {
+        x.value; // Error, x is never
+    }
+}
+function foo2(x) {
+    if (x.type === 'number') {
+        x.value; // number
+    }
+    else {
+        x.value; // string
+    }
+}
