@@ -1,6 +1,4 @@
 //// [es6MemberScoping.ts]
-
-
 class Foo {
     constructor(store: string) { }
 
@@ -18,7 +16,7 @@ class Foo2 {
 
 
 //// [es6MemberScoping.js]
-var Foo = (function () {
+var Foo = /** @class */ (function () {
     function Foo(store) {
         this._store = store; // should be an error.
     }
@@ -27,7 +25,7 @@ var Foo = (function () {
     };
     return Foo;
 }());
-var Foo2 = (function () {
+var Foo2 = /** @class */ (function () {
     function Foo2() {
     }
     Foo2.Foo2 = function () { return 0; }; // should not be an error
