@@ -1,5 +1,4 @@
 //// [es6ModuleInternalNamedImports2.ts]
-
 export module M {
     // variable
     export var M_V = 0;
@@ -44,7 +43,7 @@ export var M;
     }
     M.M_C = M_C;
     // instantiated module
-    var M_M;
+    let M_M;
     (function (M_M) {
         var x;
     })(M_M = M.M_M || (M.M_M = {}));
@@ -52,7 +51,7 @@ export var M;
     function M_F() { }
     M.M_F = M_F;
     // enum
-    var M_E;
+    let M_E;
     (function (M_E) {
     })(M_E = M.M_E || (M.M_E = {}));
     // alias
