@@ -1,10 +1,9 @@
 //// [es6modulekindWithES5Target4.ts]
-
 class E { }
 export default E;
 
 //// [es6modulekindWithES5Target4.js]
-var E = (function () {
+var E = /** @class */ (function () {
     function E() {
     }
     return E;
