@@ -88,6 +88,32 @@ const obj: Union = {
     href: 'foo',
 };
 
+// Repro from #34611
+
+interface IValue {
+  value: string
+}
+
+interface StringKeys { 
+    [propertyName: string]: IValue;
+};
+
+interface NumberKeys {
+    [propertyName: number]: IValue;
+}
+
+type ObjectDataSpecification = StringKeys | NumberKeys;
+
+
+const dataSpecification: ObjectDataSpecification = {  // Error
+    foo: "asdfsadffsd"
+};
+
+// Repro from #34611
+
+const obj1: { [x: string]: number } | { [x: number]: number } = { a: 'abc' };  // Error
+const obj2: { [x: string]: number } | { a: number } = { a: 5, c: 'abc' };  // Error
+
 
 //// [excessPropertyCheckWithUnions.js]
 "use strict";
@@ -144,3 +170,10 @@ var obj = {
     // should have error here
     href: 'foo'
 };
+;
+var dataSpecification = {
+    foo: "asdfsadffsd"
+};
+// Repro from #34611
+var obj1 = { a: 'abc' }; // Error
+var obj2 = { a: 5, c: 'abc' }; // Error
