@@ -1,5 +1,4 @@
 //// [genericClassesInModule.ts]
-
 module Foo {
 
     export class B<T>{ }
@@ -12,13 +11,13 @@ var a = new Foo.B<Foo.A>();
 //// [genericClassesInModule.js]
 var Foo;
 (function (Foo) {
-    var B = (function () {
+    var B = /** @class */ (function () {
         function B() {
         }
         return B;
     }());
     Foo.B = B;
-    var A = (function () {
+    var A = /** @class */ (function () {
         function A() {
         }
         return A;
