@@ -6,7 +6,7 @@ var c: C<I>;
 
 
 //// [genericInterfacesWithoutTypeArguments.js]
-var C = (function () {
+var C = /** @class */ (function () {
     function C() {
     }
     return C;
