@@ -4,11 +4,17 @@ declare let f2: (x: string, y: string) => void;
 declare let f3: (x: string, y: number, z: boolean) => void;
 declare let f4: (...args: [string, string] | [string, number, boolean]) => void;
 
-declare const tt: [string] | [number, boolean];
+declare const t1: [string] | [number, boolean];
+declare const t2: readonly [string] | [number, boolean];
+declare const t3: [string] | readonly [number, boolean];
+declare const t4: readonly [string] | readonly [number, boolean];
 
 f1("foo", "abc");
 f1("foo", 10, true);
-f1("foo", ...tt);
+f1("foo", ...t1);
+f1("foo", ...t2);
+f1("foo", ...t3);
+f1("foo", ...t4);
 f1("foo", 10);  // Error
 f1("foo");  // Error
 
@@ -53,6 +59,12 @@ hmm(); // okay, A = []
 hmm(1, "s"); // okay, A = [1, "s"]
 hmm("what"); // no error?  A = [] | [number, string] ?
 
+// Repro from #35066
+
+declare function foo2(...args: string[] | number[]): void;
+let x2: ReadonlyArray<string> = ["hello"];
+foo2(...x2);
+
 
 //// [genericRestParameters3.js]
 "use strict";
@@ -65,7 +77,10 @@ var __spreadArrays = (this && this.__spreadArrays) || function () {
 };
 f1("foo", "abc");
 f1("foo", 10, true);
-f1.apply(void 0, __spreadArrays(["foo"], tt));
+f1.apply(void 0, __spreadArrays(["foo"], t1));
+f1.apply(void 0, __spreadArrays(["foo"], t2));
+f1.apply(void 0, __spreadArrays(["foo"], t3));
+f1.apply(void 0, __spreadArrays(["foo"], t4));
 f1("foo", 10); // Error
 f1("foo"); // Error
 f2 = f1;
@@ -93,6 +108,8 @@ baz.apply(void 0, ca); // Error
 hmm(); // okay, A = []
 hmm(1, "s"); // okay, A = [1, "s"]
 hmm("what"); // no error?  A = [] | [number, string] ?
+var x2 = ["hello"];
+foo2.apply(void 0, x2);
 
 
 //// [genericRestParameters3.d.ts]
@@ -100,7 +117,10 @@ declare let f1: (x: string, ...args: [string] | [number, boolean]) => void;
 declare let f2: (x: string, y: string) => void;
 declare let f3: (x: string, y: number, z: boolean) => void;
 declare let f4: (...args: [string, string] | [string, number, boolean]) => void;
-declare const tt: [string] | [number, boolean];
+declare const t1: [string] | [number, boolean];
+declare const t2: readonly [string] | [number, boolean];
+declare const t3: [string] | readonly [number, boolean];
+declare const t4: readonly [string] | readonly [number, boolean];
 interface CoolArray<E> extends Array<E> {
     hello: number;
 }
@@ -111,3 +131,5 @@ declare let b: any;
 declare function baz<T>(...args: CoolArray<T>): void;
 declare const ca: CoolArray<number>;
 declare function hmm<A extends [] | [number, string]>(...args: A): void;
+declare function foo2(...args: string[] | number[]): void;
+declare let x2: ReadonlyArray<string>;
