@@ -12,7 +12,7 @@ var i2: I<C>; // should be an error
 
 
 //// [genericTypeReferencesRequireTypeArgs.js]
-var C = (function () {
+var C = /** @class */ (function () {
     function C() {
     }
     C.prototype.foo = function () { return null; };
