@@ -17,6 +17,18 @@ class B {
         // it should error here because it returns undefined
     }
 }
+class C {
+    get a() {
+        if (Math.random() > 0.5) {
+            return 0;
+        }
+
+        // it should error here because it returns undefined
+    }
+
+    set a(value: number) {
+    }
+}
 
 //// [getterControlFlowStrictNull.js]
 var A = /** @class */ (function () {
@@ -45,3 +57,20 @@ var B = /** @class */ (function () {
     });
     return B;
 }());
+var C = /** @class */ (function () {
+    function C() {
+    }
+    Object.defineProperty(C.prototype, "a", {
+        get: function () {
+            if (Math.random() > 0.5) {
+                return 0;
+            }
+            // it should error here because it returns undefined
+        },
+        set: function (value) {
+        },
+        enumerable: true,
+        configurable: true
+    });
+    return C;
+}());
