@@ -7,7 +7,7 @@ class C implements I {
 }
 
 //// [implementPublicPropertyAsPrivate.js]
-var C = (function () {
+var C = /** @class */ (function () {
     function C() {
         this.x = 0; // should raise error at class decl
     }
