@@ -10,7 +10,7 @@ class indexSig2 {
 }
 
 //// [indexerAsOptional.js]
-var indexSig2 = (function () {
+var indexSig2 = /** @class */ (function () {
     function indexSig2() {
     }
     return indexSig2;
