@@ -19,7 +19,7 @@ class Foo2 {
 
 
 //// [inferSetterParamType.js]
-var Foo = (function () {
+var Foo = /** @class */ (function () {
     function Foo() {
     }
     Object.defineProperty(Foo.prototype, "bar", {
@@ -33,7 +33,7 @@ var Foo = (function () {
     });
     return Foo;
 }());
-var Foo2 = (function () {
+var Foo2 = /** @class */ (function () {
     function Foo2() {
     }
     Object.defineProperty(Foo2.prototype, "bar", {
