@@ -12,12 +12,12 @@ interface A extends C, C2 { // error
 }
 
 //// [inheritSameNamePrivatePropertiesFromDifferentOrigins.js]
-var C = (function () {
+var C = /** @class */ (function () {
     function C() {
     }
     return C;
 }());
-var C2 = (function () {
+var C2 = /** @class */ (function () {
     function C2() {
     }
     return C2;
