@@ -14,7 +14,7 @@ class Point {
 
 //// [instanceAndStaticDeclarations1.js]
 // from spec
-var Point = (function () {
+var Point = /** @class */ (function () {
     function Point(x, y) {
         this.x = x;
         this.y = y;
@@ -25,6 +25,6 @@ var Point = (function () {
         return Math.sqrt(dx * dx + dy * dy);
     };
     Point.distance = function (p1, p2) { return p1.distance(p2); };
+    Point.origin = new Point(0, 0);
     return Point;
 }());
-Point.origin = new Point(0, 0);
