@@ -16,7 +16,7 @@ var r = i.y;
 var r2 = i.x; // error
 
 //// [interfaceExtendingClassWithPrivates.js]
-var Foo = (function () {
+var Foo = /** @class */ (function () {
     function Foo() {
     }
     return Foo;
