@@ -47,13 +47,13 @@ c["foo"];
 
 
 //// [interfaceImplementation1.js]
-var C1 = (function () {
+var C1 = /** @class */ (function () {
     function C1() {
     }
     C1.prototype.iFn = function (n, s) { };
     return C1;
 }());
-var C2 = (function () {
+var C2 = /** @class */ (function () {
     function C2() {
         this.x = 1;
     }
