@@ -10,7 +10,7 @@ class Camera implements iface{
 
 
 //// [interfaceSubtyping.js]
-var Camera = (function () {
+var Camera = /** @class */ (function () {
     function Camera(str) {
         this.str = str;
     }
