@@ -43,7 +43,7 @@ var a: Foo = {
 }
 
 //// [interfaceWithPropertyOfEveryType.js]
-var C = (function () {
+var C = /** @class */ (function () {
     function C() {
     }
     return C;
