@@ -47,7 +47,7 @@ class c1 implements a {
 var instance2 = new c1();
 
 //// [interfacedeclWithIndexerErrors.js]
-var c1 = (function () {
+var c1 = /** @class */ (function () {
     function c1() {
     }
     return c1;
