@@ -14,7 +14,7 @@ module B {
 
 
 //// [internalImportInstantiatedModuleMergedWithClassNotReferencingInstance.js]
-var A = (function () {
+var A = /** @class */ (function () {
     function A() {
     }
     return A;
