@@ -16,7 +16,7 @@ class SymbolIterator {
     }
 }
 
-class StringIterator {
+class _StringIterator {
     next() {
         return {
             value: "",
@@ -29,7 +29,7 @@ class StringIterator {
     }
 }
 
-new Foo(...[...new SymbolIterator, ...[...new StringIterator]]);
+new Foo(...[...new SymbolIterator, ...[...new _StringIterator]]);
 
 //// [iteratorSpreadInCall12.js]
 class Foo {
@@ -46,7 +46,7 @@ class SymbolIterator {
         return this;
     }
 }
-class StringIterator {
+class _StringIterator {
     next() {
         return {
             value: "",
@@ -57,4 +57,4 @@ class StringIterator {
         return this;
     }
 }
-new Foo(...[...new SymbolIterator, ...[...new StringIterator]]);
+new Foo(...[...new SymbolIterator, ...[...new _StringIterator]]);
