@@ -4,12 +4,13 @@
 var x = "hello";
 
 //// [a.ts]
-var x = 10; // Error reported so no declaration file generated?
+var x = 10; // Error reported
 
 //// [out.js]
 var x = "hello";
-var x = 10; // Error reported so no declaration file generated?
+var x = 10; // Error reported
 
 
 //// [out.d.ts]
 declare var x: string;
+declare var x: string;
