@@ -29,3 +29,5 @@ function foo() {
 //// [out.d.ts]
 declare class c {
 }
+declare function bar(): void;
+declare function foo(): void;
