@@ -6,7 +6,6 @@ class c {
 
 //// [b.ts]
 /// <reference path="c.js"/>
-// error on above reference when emitting declarations
 function foo() {
 }
 
@@ -23,13 +22,12 @@ var c = /** @class */ (function () {
 function bar() {
 }
 /// <reference path="c.js"/>
-// error on above reference when emitting declarations
 function foo() {
 }
 
 
 //// [out.d.ts]
-/// <reference path="tests/cases/compiler/c.js" />
 declare class c {
 }
+declare function bar(): void;
 declare function foo(): void;
