@@ -52,6 +52,10 @@ const obj = { foo: (a, b) => a + b };
 var E = {};
 E[""];
 
+// make sure import types in JSDoc are not resolved
+/** @type {import("should-not-be-resolved").Type} */
+var v = import(String());
+
 
 //// [jsdocInTypeScript.js]
 var T = /** @class */ (function () {
@@ -86,3 +90,6 @@ var obj = { foo: function (a, b) { return a + b; } };
 /** @enum {string} */
 var E = {};
 E[""];
+// make sure import types in JSDoc are not resolved
+/** @type {import("should-not-be-resolved").Type} */
+var v = Promise.resolve().then(function () { return require(String()); });
