@@ -5,4 +5,4 @@ const a = /* @type string */(Foo);
 
 //// [index.js]
 function Foo() { }
-var a = (Foo);
+var a = /* @type string */ (Foo);
