@@ -28,18 +28,21 @@ var foo = /** @class */ (function () {
     return foo;
 }());
 var x;
-x = <any> {test} <any></any> };
+x = <any> {test}: <any></any> };
 
 x = <any><any></any>;
  
-x = <foo>hello {<foo>} </foo>}
+x = <foo>hello {<foo>} </foo>};
 
 x = <foo test={<foo>}>hello</foo>}/>
 
-x = <foo test={<foo>}>hello{<foo>}</foo>}
+x = <foo test={<foo>}>hello{<foo>}</foo>};
 
 x = <foo>x</foo>, x = <foo />;
 
 <foo>{<foo><foo>{/foo/.test(x) ? <foo><foo></foo> : <foo><foo></foo>}</foo>}</foo>
     :
-}</></>}</></>}/></></></>;
+}
+
+    
+</></>}</></>}/></></></>;
