@@ -16,10 +16,11 @@ label: type T = {}
 
 //// [labeledStatementWithLabel_es2015.js]
 var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
+    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
     return new (P || (P = Promise))(function (resolve, reject) {
         function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
         function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
-        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
+        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
         step((generator = generator.apply(thisArg, _arguments || [])).next());
     });
 };
@@ -33,12 +34,12 @@ label: {
     (function (E) {
     })(E || (E = {}));
 }
-label: 
+label: ;
 label: class C {
 }
 label: var a = 1;
 label: let b = 1;
 label: const c = 1;
-label: 
-label: 
+label: ;
+label: ;
 label: 
