@@ -30,26 +30,26 @@ void prop9;
 
 //// [lateBoundDestructuringImplicitAnyError.js]
 var named = "foo";
-var _a = named, prop = { prop: "foo" }[_a];
+var _a = { prop: "foo" }, _b = named, prop = _a[_b];
 void prop;
 var numIndexed = null;
 var strIndexed = null;
 var numed = 6;
 var symed = Symbol();
 var symed2 = Symbol();
-var _b = named, prop2 = numIndexed[_b];
+var _c = numIndexed, _d = named, prop2 = _c[_d];
 void prop2;
-var _c = numed, prop3 = numIndexed[_c];
+var _e = numIndexed, _f = numed, prop3 = _e[_f];
 void prop3;
-var _d = named, prop4 = strIndexed[_d];
+var _g = strIndexed, _h = named, prop4 = _g[_h];
 void prop4;
-var _e = numed, prop5 = strIndexed[_e];
+var _j = strIndexed, _k = numed, prop5 = _j[_k];
 void prop5;
-var _f = symed, prop6 = numIndexed[_f];
+var _l = numIndexed, _m = symed, prop6 = _l[_m];
 void prop6;
-var _g = symed, prop7 = strIndexed[_g];
+var _o = strIndexed, _p = symed, prop7 = _o[_p];
 void prop7;
-var _h = symed2, prop8 = numIndexed[_h];
+var _q = numIndexed, _r = symed2, prop8 = _q[_r];
 void prop8;
-var _j = symed2, prop9 = strIndexed[_j];
+var _s = strIndexed, _t = symed2, prop9 = _s[_t];
 void prop9;
