@@ -12,7 +12,7 @@ module C3 {}
 interface C3 {}
 
 module C4 {}
-declare class C4 {} // error -- class declaration must preceed module declaration
+declare class C4 {} // error -- class declaration must precede module declaration
 interface C4 {}
 
 //// [mergeClassInterfaceAndModule.js]
