@@ -63,15 +63,15 @@ var B = /** @class */ (function () {
     }
     __decorate([
         PropDeco,
-        __metadata("design:type", Object)
+        __metadata("design:type", String)
     ], B.prototype, "x");
     __decorate([
         PropDeco,
-        __metadata("design:type", Object)
+        __metadata("design:type", Boolean)
     ], B.prototype, "y");
     __decorate([
         PropDeco,
-        __metadata("design:type", Object)
+        __metadata("design:type", String)
     ], B.prototype, "z");
     __decorate([
         PropDeco,
@@ -87,11 +87,11 @@ var B = /** @class */ (function () {
     ], B.prototype, "c");
     __decorate([
         PropDeco,
-        __metadata("design:type", Object)
+        __metadata("design:type", void 0)
     ], B.prototype, "d");
     __decorate([
         PropDeco,
-        __metadata("design:type", Object)
+        __metadata("design:type", typeof Symbol === "function" ? Symbol : Object)
     ], B.prototype, "e");
     __decorate([
         PropDeco,
@@ -99,15 +99,15 @@ var B = /** @class */ (function () {
     ], B.prototype, "f");
     __decorate([
         PropDeco,
-        __metadata("design:type", Object)
+        __metadata("design:type", A)
     ], B.prototype, "g");
     __decorate([
         PropDeco,
-        __metadata("design:type", Object)
+        __metadata("design:type", B)
     ], B.prototype, "h");
     __decorate([
         PropDeco,
-        __metadata("design:type", Object)
+        __metadata("design:type", typeof Symbol === "function" ? Symbol : Object)
     ], B.prototype, "j");
     return B;
 }());
