@@ -39,7 +39,7 @@
     export { foo };
     export { baz as b } from "ambient";
     export default v;
-    var C = (function () {
+    var C = /** @class */ (function () {
         function C() {
         }
         return C;
