@@ -6,7 +6,7 @@ module A {
 
 
 //// [moduleRedifinitionErrors.js]
-var A = (function () {
+var A = /** @class */ (function () {
     function A() {
     }
     return A;
