@@ -9,7 +9,7 @@ module M {
 //// [moduleReopenedTypeSameBlock.js]
 var M;
 (function (M) {
-    var C1 = (function () {
+    var C1 = /** @class */ (function () {
         function C1() {
         }
         return C1;
@@ -17,7 +17,7 @@ var M;
     M.C1 = C1;
 })(M || (M = {}));
 (function (M) {
-    var C2 = (function () {
+    var C2 = /** @class */ (function () {
         function C2() {
         }
         C2.prototype.f = function () { return null; };
