@@ -250,6 +250,55 @@ function narrowingNarrows(x: {} | undefined) {
     }
 }
 
+/* Template literals */
+
+function testUnionWithTempalte(x: Basic) {
+    switch (typeof x) {
+        case `number`: assertNumber(x); return;
+        case `boolean`: assertBoolean(x); return;
+        case `function`: assertFunction(x); return;
+        case `symbol`: assertSymbol(x); return;
+        case `object`: assertObject(x); return;
+        case `string`: assertString(x); return;
+        case `undefined`: assertUndefined(x); return;
+    }
+    assertNever(x);
+}
+
+function fallThroughTestWithTempalte(x: string | number | boolean | object) {
+    switch (typeof x) {
+        case `number`:
+            assertNumber(x)
+        case `string`:
+            assertStringOrNumber(x)
+            break;
+        default:
+            assertObject(x);
+        case `number`:
+        case `boolean`:
+            assertBooleanOrObject(x);
+            break;
+    }
+}
+
+function keyofNarrowingWithTemplate<S extends { [K in keyof S]: string }>(k: keyof S) {
+    function assertKeyofS(k1: keyof S) { }
+    switch (typeof k) {
+        case `number`: assertNumber(k); assertKeyofS(k); return;
+        case `symbol`: assertSymbol(k); assertKeyofS(k); return;
+        case `string`: assertString(k); assertKeyofS(k); return;
+    }
+}
+
+/* Both string literals and template literals */
+
+function multipleGenericFuseWithBoth<X extends L | number, Y extends R | number>(xy: X | Y): [X, number] | [Y, string] | [(X | Y)] {
+    switch (typeof xy) {
+        case `function`: return [xy, 1];
+        case 'object': return [xy, 'two'];
+        case `number`: return [xy]
+    }
+}
 
 //// [narrowingByTypeofInSwitch.js]
 function assertNever(x) {
@@ -585,3 +634,70 @@ function narrowingNarrows(x) {
             return;
     }
 }
+/* Template literals */
+function testUnionWithTempalte(x) {
+    switch (typeof x) {
+        case "number":
+            assertNumber(x);
+            return;
+        case "boolean":
+            assertBoolean(x);
+            return;
+        case "function":
+            assertFunction(x);
+            return;
+        case "symbol":
+            assertSymbol(x);
+            return;
+        case "object":
+            assertObject(x);
+            return;
+        case "string":
+            assertString(x);
+            return;
+        case "undefined":
+            assertUndefined(x);
+            return;
+    }
+    assertNever(x);
+}
+function fallThroughTestWithTempalte(x) {
+    switch (typeof x) {
+        case "number":
+            assertNumber(x);
+        case "string":
+            assertStringOrNumber(x);
+            break;
+        default:
+            assertObject(x);
+        case "number":
+        case "boolean":
+            assertBooleanOrObject(x);
+            break;
+    }
+}
+function keyofNarrowingWithTemplate(k) {
+    function assertKeyofS(k1) { }
+    switch (typeof k) {
+        case "number":
+            assertNumber(k);
+            assertKeyofS(k);
+            return;
+        case "symbol":
+            assertSymbol(k);
+            assertKeyofS(k);
+            return;
+        case "string":
+            assertString(k);
+            assertKeyofS(k);
+            return;
+    }
+}
+/* Both string literals and template literals */
+function multipleGenericFuseWithBoth(xy) {
+    switch (typeof xy) {
+        case "function": return [xy, 1];
+        case 'object': return [xy, 'two'];
+        case "number": return [xy];
+    }
+}
