@@ -21,6 +21,10 @@ function f3(): never {
 function f4(): never {
 }
 
+for (const n of f4()) {}
+for (const n in f4()) {}
+
+
 //// [neverTypeErrors2.js]
 function f1() {
     var x;
@@ -40,3 +44,7 @@ function f3() {
 }
 function f4() {
 }
+for (var _i = 0, _a = f4(); _i < _a.length; _i++) {
+    var n = _a[_i];
+}
+for (var n in f4()) { }
