@@ -5,6 +5,8 @@ declare class Something
 {
     private static someStaticVar;
     private someVar;
+    private get getter();
+    private set setter(v);
 }
 
 //// [app.ts]
