@@ -16,6 +16,10 @@ function f3(z: number): number {
 
 // error: `this` is `window`, but is still of type `any`
 let f4: (b: number) => number = b => this.c + b;
+let f5 = () => () => this;
+
+let f6 = function() { return () => this; };
+let f7 = function() { return function() { return this } };
 
 
 //// [noImplicitThisFunctions.js]
@@ -34,3 +38,9 @@ function f3(z) {
 }
 // error: `this` is `window`, but is still of type `any`
 var f4 = function (b) { return _this.c + b; };
+var f5 = function () { return function () { return _this; }; };
+var f6 = function () {
+    var _this = this;
+    return function () { return _this; };
+};
+var f7 = function () { return function () { return this; }; };
