@@ -8,4 +8,4 @@ let gg = f() ?? 'foo'
 //// [nullishCoalescingOperator10.js]
 "use strict";
 var _a;
-var gg = (_a = f(), (_a !== null && _a !== void 0 ? _a : 'foo'));
+var gg = (_a = f()) !== null && _a !== void 0 ? _a : 'foo';
