@@ -22,12 +22,12 @@ const aa9 = a9 ?? 'whatever'
 
 //// [nullishCoalescingOperator2.js]
 "use strict";
-var aa1 = (a1 !== null && a1 !== void 0 ? a1 : 'whatever');
-var aa2 = (a2 !== null && a2 !== void 0 ? a2 : 'whatever');
-var aa3 = (a3 !== null && a3 !== void 0 ? a3 : 'whatever');
-var aa4 = (a4 !== null && a4 !== void 0 ? a4 : 'whatever');
-var aa5 = (a5 !== null && a5 !== void 0 ? a5 : 'whatever');
-var aa6 = (a6 !== null && a6 !== void 0 ? a6 : 'whatever');
-var aa7 = (a7 !== null && a7 !== void 0 ? a7 : 'whatever');
-var aa8 = (a8 !== null && a8 !== void 0 ? a8 : 'whatever');
-var aa9 = (a9 !== null && a9 !== void 0 ? a9 : 'whatever');
+var aa1 = a1 !== null && a1 !== void 0 ? a1 : 'whatever';
+var aa2 = a2 !== null && a2 !== void 0 ? a2 : 'whatever';
+var aa3 = a3 !== null && a3 !== void 0 ? a3 : 'whatever';
+var aa4 = a4 !== null && a4 !== void 0 ? a4 : 'whatever';
+var aa5 = a5 !== null && a5 !== void 0 ? a5 : 'whatever';
+var aa6 = a6 !== null && a6 !== void 0 ? a6 : 'whatever';
+var aa7 = a7 !== null && a7 !== void 0 ? a7 : 'whatever';
+var aa8 = a8 !== null && a8 !== void 0 ? a8 : 'whatever';
+var aa9 = a9 !== null && a9 !== void 0 ? a9 : 'whatever';
