@@ -8,4 +8,4 @@ let gg = f ?? (abc => { void abc.toLowerCase() })
 //// [nullishCoalescingOperator9.js]
 "use strict";
 var g = f || (function (abc) { void abc.toLowerCase(); });
-var gg = (f !== null && f !== void 0 ? f : (function (abc) { void abc.toLowerCase(); }));
+var gg = f !== null && f !== void 0 ? f : (function (abc) { void abc.toLowerCase(); });
