@@ -21,6 +21,7 @@ var x = {
 var v = { class };  // error
 
 //// [objectLiteralShorthandPropertiesErrorFromNotUsingIdentifier.js]
+var _a;
 // errors
 var y = {
     "stringLiteral": ,
@@ -33,9 +34,12 @@ var y = {
     "class": ,
     "typeof": 
 };
-var x = {
-    a: .b,
-    a: ["ss"],
-    a: [1]
-};
+var x = (_a = {
+        a: a, : .b,
+        a: a
+    },
+    _a["ss"] = ,
+    _a.a = a,
+    _a[1] = ,
+    _a);
 var v = { "class":  }; // error
