@@ -25,7 +25,7 @@ var n;
 (function (n) {
     var z = 10000;
     n.y = {
-        m: .x // error
+        m: m, : .x // error
     };
 })(n || (n = {}));
 m.y.x;
