@@ -19,8 +19,8 @@ function fn(y, set) {
 var C = /** @class */ (function () {
     function C(y, x // expected to work, but actually doesn't
     ) {
-        if (x === void 0) { x = fn(y, function (y, x) { return y.x = x; }); } // expected to work, but actually doesn't
-        this.x = x; // expected to work, but actually doesn't
+        if (x === void 0) { x = fn(y, function (y, x) { return y.x = x; }); }
+        this.x = x;
     }
     return C;
 }());
