@@ -1,5 +1,5 @@
 //// [parseErrorInHeritageClause1.ts]
-class C extends A # {
+class C extends A ¬ {
 }
 
 //// [parseErrorInHeritageClause1.js]
