@@ -6,7 +6,7 @@ static public intI<T>() {}
 
 
 //// [parserAccessibilityAfterStatic10.js]
-var Outer = (function () {
+var Outer = /** @class */ (function () {
     function Outer() {
     }
     Outer.intI = function () { };
