@@ -6,7 +6,7 @@ static public<T>() {}
 
 
 //// [parserAccessibilityAfterStatic14.js]
-var Outer = (function () {
+var Outer = /** @class */ (function () {
     function Outer() {
     }
     Outer.public = function () { };
