@@ -4,7 +4,7 @@ class C {
 }
 
 //// [parserMemberAccessorDeclaration16.js]
-var C = (function () {
+var C = /** @class */ (function () {
     function C() {
     }
     Object.defineProperty(C.prototype, "Foo", {
