@@ -10,7 +10,7 @@ var C = /** @class */ (function () {
     function C() {
     }
     C.prototype.M = function () {
-        _super.prototype..call(this, 0);
+        _this = _super.call(this, 0) || this;
     };
     return C;
 }());
