@@ -6,7 +6,7 @@ class C {
 }
 
 //// [parserSuperExpression3.js]
-var C = (function () {
+var C = /** @class */ (function () {
     function C() {
     }
     C.prototype.M = function () {
