@@ -14,7 +14,7 @@ module M1.M2 {
 }
 
 //// [parserSuperExpression4.js]
-var C = (function () {
+var C = /** @class */ (function () {
     function C() {
     }
     C.prototype.foo = function () {
@@ -26,7 +26,7 @@ var M1;
 (function (M1) {
     var M2;
     (function (M2) {
-        var C = (function () {
+        var C = /** @class */ (function () {
             function C() {
             }
             C.prototype.foo = function () {
