@@ -14,6 +14,6 @@ var y: {
 var _a;
 var x = (_a = {},
     _a[x] = string,
-    _a.string = ,
+    _a.string = string,
     _a);
 var y;
