@@ -12,7 +12,7 @@ module C {
 
 //// [privateStaticNotAccessibleInClodule.js]
 // Any attempt to access a private property member outside the class body that contains its declaration results in a compile-time error.
-var C = (function () {
+var C = /** @class */ (function () {
     function C() {
     }
     return C;
