@@ -7,7 +7,7 @@ f.privProp;
 
 
 //// [propertyAccessibility1.js]
-var Foo = (function () {
+var Foo = /** @class */ (function () {
     function Foo() {
         this.privProp = 0;
     }
