@@ -1,46 +1,68 @@
 //// [quotedConstructors.ts]
 class C {
-    "constructor"() {} // Error in 3.5
+    "constructor"() {
+        console.log(this);
+    }
 }
 
 class D {
-    'constructor'() {} // Error in 3.5
+    'constructor'() {
+        console.log(this);
+    }
 }
 
 class E {
-    ['constructor']() {}
+    ['constructor']() {
+        console.log(this);
+    }
 }
 
 new class {
-    "constructor"() {} // Error in 3.5
+    "constructor"() {
+        console.log(this);
+    }
 };
 
 var o = { "constructor"() {} };
 
+class F {
+    "\x63onstructor"() {
+        console.log(this);
+    }
+}
+
 
 //// [quotedConstructors.js]
 var C = /** @class */ (function () {
     function C() {
+        console.log(this);
     }
-    C.prototype["constructor"] = function () { }; // Error in 3.5
     return C;
 }());
 var D = /** @class */ (function () {
     function D() {
+        console.log(this);
     }
-    D.prototype['constructor'] = function () { }; // Error in 3.5
     return D;
 }());
 var E = /** @class */ (function () {
     function E() {
     }
-    E.prototype['constructor'] = function () { };
+    E.prototype['constructor'] = function () {
+        console.log(this);
+    };
     return E;
 }());
 new /** @class */ (function () {
     function class_1() {
+        console.log(this);
     }
-    class_1.prototype["constructor"] = function () { }; // Error in 3.5
     return class_1;
 }());
 var o = { "constructor": function () { } };
+var F = /** @class */ (function () {
+    function F() {
+        console.log(this);
+    }
+    return F;
+}());
