@@ -8,7 +8,7 @@ var c1 = new C1(0);
 
 
 //// [raiseErrorOnParameterProperty.js]
-var C1 = (function () {
+var C1 = /** @class */ (function () {
     function C1(x) {
         this.x = x;
     }
