@@ -8,7 +8,7 @@ class B {
 }
 
 //// [recursiveProperties.js]
-var A = (function () {
+var A = /** @class */ (function () {
     function A() {
     }
     Object.defineProperty(A.prototype, "testProp", {
@@ -18,7 +18,7 @@ var A = (function () {
     });
     return A;
 }());
-var B = (function () {
+var B = /** @class */ (function () {
     function B() {
     }
     Object.defineProperty(B.prototype, "testProp", {
