@@ -8,7 +8,7 @@ class C1 implements I1 {
 }
 
 //// [requiredInitializedParameter2.js]
-var C1 = (function () {
+var C1 = /** @class */ (function () {
     function C1() {
     }
     C1.prototype.method = function (a, b) {
