@@ -4,7 +4,7 @@ class C {
 }
 
 //// [restParamModifier2.js]
-var C = (function () {
+var C = /** @class */ (function () {
     function C() {
         var rest = [];
         for (var _i = 0; _i < arguments.length; _i++) {
