@@ -7,7 +7,7 @@ class selfReferencingFile3 {
 
 //// [selfReferencingFile3.js]
 ///<reference path='./selfReferencingFile3.ts'/>
-var selfReferencingFile3 = (function () {
+var selfReferencingFile3 = /** @class */ (function () {
     function selfReferencingFile3() {
     }
     return selfReferencingFile3;
