@@ -117,120 +117,120 @@ function foo({a = 4, b = { x: 5 }}) {
 
 //// [shorthandPropertyAssignmentsInDestructuring.js]
 (function () {
+    var _a;
     var s0;
-    for (var _i = 0, _a = [{ s0: 1 }]; _i < _a.length; _i++) {
-        _b = _a[_i].s0, s0 = _b === void 0 ? 5 : _b;
+    for (var _i = 0, _b = [{ s0: 1 }]; _i < _b.length; _i++) {
+        _a = _b[_i].s0, s0 = _a === void 0 ? 5 : _a;
     }
-    var _b;
 });
 (function () {
+    var _a;
     var s0;
-    for (var _i = 0, _a = [{ s0: 1 }]; _i < _a.length; _i++) {
-        _b = _a[_i].s0, s0 = _b === void 0 ? 5 : _b;
+    for (var _i = 0, _b = [{ s0: 1 }]; _i < _b.length; _i++) {
+        _a = _b[_i].s0, s0 = _a === void 0 ? 5 : _a;
     }
-    var _b;
 });
 (function () {
+    var _a;
     var s1;
-    for (var _i = 0, _a = [{}]; _i < _a.length; _i++) {
-        _b = _a[_i].s1, s1 = _b === void 0 ? 5 : _b;
+    for (var _i = 0, _b = [{}]; _i < _b.length; _i++) {
+        _a = _b[_i].s1, s1 = _a === void 0 ? 5 : _a;
     }
-    var _b;
 });
 (function () {
+    var _a;
     var s1;
-    for (var _i = 0, _a = [{}]; _i < _a.length; _i++) {
-        _b = _a[_i].s1, s1 = _b === void 0 ? 5 : _b;
+    for (var _i = 0, _b = [{}]; _i < _b.length; _i++) {
+        _a = _b[_i].s1, s1 = _a === void 0 ? 5 : _a;
     }
-    var _b;
 });
 (function () {
+    var _a;
     var s2;
-    for (var _i = 0, _a = [{ s2: "" }]; _i < _a.length; _i++) {
-        _b = _a[_i].s2, s2 = _b === void 0 ? 5 : _b;
+    for (var _i = 0, _b = [{ s2: "" }]; _i < _b.length; _i++) {
+        _a = _b[_i].s2, s2 = _a === void 0 ? 5 : _a;
     }
-    var _b;
 });
 (function () {
+    var _a;
     var s2;
-    for (var _i = 0, _a = [{ s2: "" }]; _i < _a.length; _i++) {
-        _b = _a[_i].s2, s2 = _b === void 0 ? 5 : _b;
+    for (var _i = 0, _b = [{ s2: "" }]; _i < _b.length; _i++) {
+        _a = _b[_i].s2, s2 = _a === void 0 ? 5 : _a;
     }
-    var _b;
 });
 (function () {
+    var _a;
     var s3;
-    for (var _i = 0, _a = [{ s3: "" }]; _i < _a.length; _i++) {
-        _b = _a[_i].s3, s3 = _b === void 0 ? 5 : _b;
+    for (var _i = 0, _b = [{ s3: "" }]; _i < _b.length; _i++) {
+        _a = _b[_i].s3, s3 = _a === void 0 ? 5 : _a;
     }
-    var _b;
 });
 (function () {
+    var _a;
     var s3;
-    for (var _i = 0, _a = [{ s3: "" }]; _i < _a.length; _i++) {
-        _b = _a[_i].s3, s3 = _b === void 0 ? 5 : _b;
+    for (var _i = 0, _b = [{ s3: "" }]; _i < _b.length; _i++) {
+        _a = _b[_i].s3, s3 = _a === void 0 ? 5 : _a;
     }
-    var _b;
 });
 (function () {
+    var _a;
     var y;
     (_a = { y: 1 }.y, y = _a === void 0 ? 5 : _a);
-    var _a;
 });
 (function () {
+    var _a;
     var y;
     (_a = { y: 1 }.y, y = _a === void 0 ? 5 : _a);
-    var _a;
 });
 (function () {
+    var _a;
     var y0;
     (_a = { y0: 1 }.y0, y0 = _a === void 0 ? 5 : _a);
-    var _a;
 });
 (function () {
+    var _a;
     var y0;
     (_a = { y0: 1 }.y0, y0 = _a === void 0 ? 5 : _a);
-    var _a;
 });
 (function () {
+    var _a;
     var y1;
     (_a = {}.y1, y1 = _a === void 0 ? 5 : _a);
-    var _a;
 });
 (function () {
+    var _a;
     var y1;
     (_a = {}.y1, y1 = _a === void 0 ? 5 : _a);
-    var _a;
 });
 (function () {
+    var _a, _b, _c;
     var y2, y3;
     (_a = {}, _b = _a.y2, y2 = _b === void 0 ? 5 : _b, _c = _a.y3, y3 = _c === void 0 ? { x: 1 } : _c);
-    var _a, _b, _c;
 });
 (function () {
+    var _a, _b, _c;
     var y2, y3;
     (_a = {}, _b = _a.y2, y2 = _b === void 0 ? 5 : _b, _c = _a.y3, y3 = _c === void 0 ? { x: 1 } : _c);
-    var _a, _b, _c;
 });
 (function () {
+    var _a, _b, _c;
     var y4, y5;
     (_a = {}, _b = _a.y4, y4 = _b === void 0 ? 5 : _b, _c = _a.y5, y5 = _c === void 0 ? { x: 1 } : _c);
-    var _a, _b, _c;
 });
 (function () {
+    var _a, _b, _c;
     var y4, y5;
     (_a = {}, _b = _a.y4, y4 = _b === void 0 ? 5 : _b, _c = _a.y5, y5 = _c === void 0 ? { x: 1 } : _c);
-    var _a, _b, _c;
 });
 (function () {
+    var _a;
     var z;
     (_a = { z: { x: 1 } }.z, z = _a === void 0 ? { x: 5 } : _a);
-    var _a;
 });
 (function () {
+    var _a;
     var z;
     (_a = { z: { x: 1 } }.z, z = _a === void 0 ? { x: 5 } : _a);
-    var _a;
 });
 (function () {
     var a = { s: s };
