@@ -37,9 +37,9 @@ var o1 = __assign({}, undefinedUnion);
 var o2;
 var o2 = __assign({}, nullUnion);
 var o3;
-var o3 = __assign({}, undefinedUnion, nullUnion);
-var o3 = __assign({}, nullUnion, undefinedUnion);
+var o3 = __assign(__assign({}, undefinedUnion), nullUnion);
+var o3 = __assign(__assign({}, nullUnion), undefinedUnion);
 var o4;
-var o4 = __assign({}, undefinedUnion, undefinedUnion);
+var o4 = __assign(__assign({}, undefinedUnion), undefinedUnion);
 var o5;
-var o5 = __assign({}, nullUnion, nullUnion);
+var o5 = __assign(__assign({}, nullUnion), nullUnion);
