@@ -14,7 +14,7 @@ interface I {
 }
 
 //// [stringIndexerAndConstructor.js]
-var C = (function () {
+var C = /** @class */ (function () {
     function C() {
     }
     C.v = function () { };
