@@ -32,7 +32,7 @@ var b = {
 //// [stringLiteralTypesInImplementationSignatures2.js]
 // String literal types are only valid in overload signatures
 function foo(x) { }
-var C = (function () {
+var C = /** @class */ (function () {
     function C() {
     }
     C.prototype.foo = function (x) { };
