@@ -36,9 +36,7 @@ var C = /** @class */ (function () {
 var D = /** @class */ (function (_super) {
     __extends(D, _super);
     function D() {
-        var _this = this;
-        _super.prototype..call(_this);
-        return _this;
+        return _super.call(this) || this;
     }
     D.prototype.bar = function () {
         _super.prototype.bar.call(this, null);
