@@ -11,12 +11,12 @@ class Vector {
 //// [thisInArrowFunctionInStaticInitializer1.js]
 var _this = this;
 function log(a) { }
-var Vector = (function () {
+var Vector = /** @class */ (function () {
     function Vector() {
     }
+    Vector.foo = function () {
+        // 'this' should not be available in a static initializer.
+        log(_this);
+    };
     return Vector;
 }());
-Vector.foo = function () {
-    // 'this' should not be available in a static initializer.
-    log(_this);
-};
