@@ -3,20 +3,30 @@ class P {
     x = this;
     static y = this;
 
-    constructor(public z = this, zz = this) { }
+    constructor(public z = this, zz = this, zzz = (p = this) => this) {
+        zzz = (p = this) => this;
+    }
 
     foo(zz = this) { zz.x; }
     static bar(zz = this) { zz.y; }
 }
 
 //// [thisInConstructorParameter2.js]
-var _this = this;
 var P = /** @class */ (function () {
-    function P(z, zz) {
+    function P(z, zz, zzz) {
+        var _this = this;
         if (z === void 0) { z = this; }
         if (zz === void 0) { zz = this; }
+        if (zzz === void 0) { zzz = function (p) {
+            if (p === void 0) { p = _this; }
+            return _this;
+        }; }
         this.z = z;
         this.x = this;
+        zzz = function (p) {
+            if (p === void 0) { p = _this; }
+            return _this;
+        };
     }
     P.prototype.foo = function (zz) {
         if (zz === void 0) { zz = this; }
