@@ -15,17 +15,17 @@ class Derived {
 
 
 //// [thisTypeErrors2.js]
-var Base = (function () {
+var Base = /** @class */ (function () {
     function Base(a) {
     }
     return Base;
 }());
-var Generic = (function () {
+var Generic = /** @class */ (function () {
     function Generic() {
     }
     return Generic;
 }());
-var Derived = (function () {
+var Derived = /** @class */ (function () {
     function Derived(host) {
         this.host = host;
         var self = this;
