@@ -14,7 +14,7 @@ var Obj1: Obj1type;
 interface Obj2type {
 	new(n: string): { q?: number; pr: any };
 }
-var obj2: Obj2type;
+var Obj2: Obj2type;
 <Obj2 x={10} />; // OK
 
 interface Obj3type {
@@ -22,6 +22,9 @@ interface Obj3type {
 }
 var Obj3: Obj3type;
 <Obj3 x={10} />; // Error
+var attributes: any;
+<Obj3 {...attributes} />; // Error
+<Obj3 {...{}} />; // OK
 
 interface Obj4type {
 	new(n: string): { x: number; pr: { x: number; } };
@@ -34,10 +37,13 @@ var Obj4: Obj4type;
 //// [file.jsx]
 var Obj1;
 <Obj1 x={10}/>; // OK
-var obj2;
+var Obj2;
 <Obj2 x={10}/>; // OK
 var Obj3;
 <Obj3 x={10}/>; // Error
+var attributes;
+<Obj3 {...attributes}/>; // Error
+<Obj3 {...{}}/>; // OK
 var Obj4;
 <Obj4 x={10}/>; // OK
 <Obj4 x={'10'}/>; // Error
