@@ -10,9 +10,7 @@ var y = { a: 1 };
 
 //// [file.jsx]
 function foo() {
-    var x = <div>  {}div>
+    var x = <div>  {} </div>;
 }
 // Shouldn't see any errors down here
-var y = {a} 1 };
-    </>;
-}
+var y = { a: 1 };
