@@ -51,7 +51,7 @@ function f(x) {
     x[100];
     x['hello'];
 }
-var MyClass = (function () {
+var MyClass = /** @class */ (function () {
     function MyClass() {
     }
     MyClass.displayTree1 = function (tree) {
