@@ -3,7 +3,7 @@ class C<T,> {
 }
 
 //// [typeParameterListWithTrailingComma1.js]
-var C = (function () {
+var C = /** @class */ (function () {
     function C() {
     }
     return C;
