@@ -1,5 +1,4 @@
 //// [unusedClassesinModule1.ts]
-
 module A {
     class Calculator {
         public handelChar() {
@@ -10,7 +9,7 @@ module A {
 //// [unusedClassesinModule1.js]
 var A;
 (function (A) {
-    var Calculator = (function () {
+    var Calculator = /** @class */ (function () {
         function Calculator() {
         }
         Calculator.prototype.handelChar = function () {
