@@ -1,5 +1,4 @@
 //// [unusedMultipleParameters1InMethodDeclaration.ts]
-
 class Dummy {
     public greeter(person: string, person2: string) {
         var unused = 20;
@@ -8,7 +7,7 @@ class Dummy {
 }
 
 //// [unusedMultipleParameters1InMethodDeclaration.js]
-var Dummy = (function () {
+var Dummy = /** @class */ (function () {
     function Dummy() {
     }
     Dummy.prototype.greeter = function (person, person2) {
