@@ -1,5 +1,4 @@
 //// [unusedPrivateMethodInClass4.ts]
-
 class greeter {
     private function1() {
         var y = 10;
@@ -19,7 +18,7 @@ class greeter {
 }
 
 //// [unusedPrivateMethodInClass4.js]
-var greeter = (function () {
+var greeter = /** @class */ (function () {
     function greeter() {
     }
     greeter.prototype.function1 = function () {
