@@ -5,14 +5,14 @@ class greeter {
     public  z: string;
 
     constructor() {
-        this.x = "dummy value";
+        this.x;
     }
 }
 
 //// [unusedPrivateVariableInClass5.js]
 var greeter = /** @class */ (function () {
     function greeter() {
-        this.x = "dummy value";
+        this.x;
     }
     return greeter;
 }());
