@@ -1,5 +1,4 @@
 //// [unusedVariablesinNamespaces2.ts]
-
 namespace Validation {
     const lettersRegexp = /^[A-Za-z]+$/;
     const numberRegexp = /^[0-9]+$/;
@@ -16,7 +15,7 @@ var Validation;
 (function (Validation) {
     var lettersRegexp = /^[A-Za-z]+$/;
     var numberRegexp = /^[0-9]+$/;
-    var LettersOnlyValidator = (function () {
+    var LettersOnlyValidator = /** @class */ (function () {
         function LettersOnlyValidator() {
         }
         LettersOnlyValidator.prototype.isAcceptable = function (s2) {
