@@ -93,4 +93,30 @@ let xyz: LikeA | LikeB = {
     }
 };
 
-xyz;
\ No newline at end of file
+xyz;
+
+// Repro from #29168
+
+interface TestObject {
+  type?: 'object';
+  items: {
+    [k: string]: TestGeneric;
+  };
+}
+
+interface TestString {
+  type: 'string';
+}
+
+type TestGeneric = (TestString | TestObject) & { [k: string]: any; };
+
+const test: TestGeneric = {
+  items: {
+    hello: { type: 'string' },
+    world: {
+      items: {
+        nested: { type: 'string' }
+      }
+    }
+  }
+};
