@@ -17,7 +17,7 @@ async function countEverything(): Promise<number> {
     const [resultA, resultB] = await Promise.all([
         providerA(),
         providerB(),
-    ]);
+    ] as const);
 
     const dataA: A[] = resultA;
     const dataB: B[] = resultB;
@@ -25,4 +25,4 @@ async function countEverything(): Promise<number> {
         return dataA.length + dataB.length;
     }
     return 0;
-}
\ No newline at end of file
+}
