@@ -38,4 +38,7 @@ type i09t03 = i09<1, 2, 3>; // ok
 type i09t04 = i09<1, 2, 3, 4>; // error
 
 interface i10 { x: T; } // error
-interface i10<T = number> {}
\ No newline at end of file
+interface i10<T = number> {}
+
+// https://github.com/Microsoft/TypeScript/issues/16221
+interface SelfReference<T = SelfReference> {}
\ No newline at end of file
