@@ -10,4 +10,4 @@ declare function shouldBeIdentity<T, U>(p: DoNothingAlias<T, U>): MyPromise<T, U
 
 declare const p1: MyPromise<boolean, any>;
 var p2 = shouldBeIdentity(p1);
-var p2: MyPromise<boolean, {}>;
+var p2: MyPromise<boolean, any>;
