@@ -5,4 +5,4 @@
 var x = 10;
 
 // @filename: b.js
-var x = "hello"; // No error is recorded here and declaration file will show this as number
\ No newline at end of file
+var x = "hello"; // Error is recorded here, but suppressed because the js file isn't checked
\ No newline at end of file
