@@ -15,7 +15,7 @@ t = [];               // Error
 t = [1];              // Error
 t = [1, "hello"];     // Ok
 t = ["hello", 1];     // Error
-t = [1, "hello", 2];  // Ok
+t = [1, "hello", 2];  // Error
 
 var tf: [string, (x: string) => number] = ["hello", x => x.length];
 
