@@ -1,13 +1,15 @@
-//@noUnusedLocals:true
+// @noUnusedLocals:true
+
+// @Filename: /a.ts
+import * as _ from "./a";
 
 for (const _ of []) { }
 
 for (const _ in []) { }
 
-namespace M {
+namespace _ns {
     let _;
     for (const _ of []) { }
 
     for (const _ in []) { }
 }
-    
\ No newline at end of file
