@@ -54,10 +54,10 @@ type Weak = {
         b?: number
     }
 }
-declare let unknown: {
+declare let propertiesWrong: {
     properties: {
         wrong: string
     }
 }
-let weak: Weak & Spoiler = unknown
+let weak: Weak & Spoiler = propertiesWrong
 
