@@ -3,6 +3,8 @@
 class A {
     x() {
     }
+    y() {
+    }
 }
 
 class B extends A {
@@ -10,6 +12,8 @@ class B extends A {
     async simple() {
         // call with property access
         super.x();
+        // call additional property.
+        super.y();
 
         // call with element access
         super["x"]();
@@ -49,4 +53,4 @@ class B extends A {
         // destructuring assign with element access
         ({ f: super["x"] } = { f });
     }
-}
\ No newline at end of file
+}
