@@ -1,4 +1,5 @@
 // @strict: true
+// @target:es2015
 // @declaration: true
 
 // Properties with non-undefined types require initialization
@@ -8,6 +9,10 @@ class C1 {
     b: number | undefined;
     c: number | null;  // Error
     d?: number;
+    #f: number; //Error
+    #g: number | undefined;
+    #h: number | null; //Error
+    #i?: number;
 }
 
 // No strict initialization checks in ambient contexts
@@ -17,6 +22,11 @@ declare class C2 {
     b: number | undefined;
     c: number | null;
     d?: number;
+    
+    #f: number;
+    #g: number | undefined;
+    #h: number | null;
+    #i?: number;
 }
 
 // No strict initialization checks for static members
@@ -34,14 +44,19 @@ class C4 {
     a = 0;
     b: number = 0;
     c: string = "abc";
+    #d = 0
+    #e: number = 0
+    #f: string= "abc"
 }
 
 // Assignment in constructor satisfies strict initialization check
 
 class C5 {
     a: number;
+    #b: number;
     constructor() {
         this.a = 0;
+        this.#b = 0;
     }
 }
 
@@ -49,22 +64,27 @@ class C5 {
 
 class C6 {
     a: number;  // Error
+    #b: number
     constructor(cond: boolean) {
         if (cond) {
             return;
         }
         this.a = 0;
+        this.#b = 0;
     }
 }
 
 class C7 {
     a: number;
+    #b: number;
     constructor(cond: boolean) {
         if (cond) {
             this.a = 1;
+            this.#b = 1;
             return;
         }
         this.a = 0;
+        this.#b = 1;
     }
 }
 
@@ -92,10 +112,13 @@ class C10 {
     a: number;
     b: number;
     c?: number;
+    #d: number;
     constructor() {
         let x = this.a;  // Error
         this.a = this.b;  // Error
+        this.b = this.#d //Error
         this.b = x;
+        this.#d = x;
         let y = this.c;
     }
 }
@@ -106,7 +129,9 @@ declare function someValue(): any;
 
 class C11 {
     a: number;
+    #b: number;
     constructor() {
         this.a = someValue();
+        this.#b = someValue();
     }
 }
