@@ -4,6 +4,7 @@ declare function prefix(s: string, a?: number, b?: number): void;
 declare function rest(s: string, a?: number, b?: number,  ...rest: number[]): void;
 declare function normal(s: string): void;
 declare function thunk(): string;
+declare function prefix2(s: string, n: number, a?: number, b?: number): void;
 
 declare var ns: number[];
 declare var mixed: (number | string)[];
@@ -32,3 +33,4 @@ rest("f", ...tuple)
 prefix(...ns) // required parameters are required
 prefix(...mixed)
 prefix(...tuple)
+prefix2("g", ...ns);
