@@ -3,8 +3,8 @@
 // @checkJs: true
 // @target: es3
 // @filename: index.js
-Common.Item = class I {}
-Common.Object = class extends Common.Item {}
+First.Item = class I {}
+Common.Object = class extends First.Item {}
 
 Workspace.Object = class extends Common.Object {}
 
@@ -12,5 +12,6 @@ Workspace.Object = class extends Common.Object {}
 var am;
 
 // @filename: roots.js
+var First = {};
 var Common = {};
 var Workspace = {};
