@@ -59,4 +59,15 @@ type DeepReadonlyFoo = {
 };
 
 var x1: DeepReadonly<Foo>;
-var x1: DeepReadonlyFoo;
\ No newline at end of file
+var x1: DeepReadonlyFoo;
+
+// Repro from #13232
+
+type Z = { a: number };
+type Clone<T> = {
+  [P in keyof (T & {})]: T[P];
+};
+type M = Clone<Z>; // M should be { a: number }
+
+var z1: Z;
+var z1: Clone<Z>;
