@@ -18,4 +18,7 @@ function f3(): never {
 }
 
 function f4(): never {
-}
\ No newline at end of file
+}
+
+for (const n of f4()) {}
+for (const n in f4()) {}
