@@ -15,4 +15,9 @@ var a: {
 var b = <U extends T, T extends U>() => { }
 var b2 = <T extends U, U extends V, V extends T>() => { }
 
-class D<U extends T, T extends V, V extends T> { }
\ No newline at end of file
+class D<U extends T, T extends V, V extends T> { }
+
+// Repro from #25740
+
+type Foo<T> = [T] extends [number] ? {} : {};
+function foo<S extends Foo<S>>() {}
