@@ -7,8 +7,5 @@
 ////var x: m1c./*1*/;
 ////var /*2*/r = m1c;
 
-goTo.marker('1');
-verify.completionListContains('I');
-verify.not.completionListContains('foo');
-
+verify.completions({ marker: "1", exact: "I" });
 verify.quickInfoAt("2", "var r: number");
