@@ -5,11 +5,10 @@
 ////var x: m2g./*1*/;
 ////var /*2*/r = m2g/*3*/;
 
-goTo.marker('1');
-verify.completionListContains('C');
+verify.completions({ marker: "1", exact: "C" });
 
 edit.insert('C.');
-verify.not.completionListContains('foo');
+verify.completions({ exact: undefined });
 edit.backspace(1);
 
 verify.quickInfoAt("2", "var r: typeof m2g");
