@@ -6,12 +6,13 @@
 ////export = foo;
 
 // @Filename: index.ts
-////[|import * as foo from "./foo";|]
-////foo();
+////import * as foo from "./foo";
+////[|foo|]();
 
 goTo.file(1);
 verify.codeFix({
     description: `Replace import with 'import foo = require("./foo");'.`,
-    newRangeContent: `import foo = require("./foo");`,
+    newFileContent: `import foo = require("./foo");
+foo();`,
     index: 1,
 });
