@@ -5,6 +5,7 @@
 ////    private y: number;
 ////    protected z: number;
 ////    public w: number;
+////    public useY() { this.y; }
 ////}
 ////
 ////class C implements A {[| |]}
@@ -17,11 +18,15 @@ verify.codeFix({
     private y: number;
     protected z: number;
     public w: number;
+    public useY() { this.y; }
 }
 
 class C implements A {
     x: number;
     protected z: number;
     public w: number;
+    public useY(): void {
+        throw new Error("Method not implemented.");
+    }
 }`,
 });
