@@ -1,18 +1,28 @@
 /// <reference path='fourslash.ts' />
 
-//// interface I {
-////     method(a: number, ...b: string[]): boolean;
-////     method(a: string, ...b: number[]): Function;
-////     method(a: string): Function;
-//// }
+////interface I {
+////    method(a: number, ...b: string[]): boolean;
+////    method(a: string, ...b: number[]): Function;
+////    method(a: string): Function;
+////}
 ////
-//// class C implements I {[| |]}
+////class C implements I {}
 
-verify.rangeAfterCodeFix(`
+verify.codeFix({
+    description: "Implement interface 'I'",
+    newFileContent:
+`interface I {
+    method(a: number, ...b: string[]): boolean;
+    method(a: string, ...b: number[]): Function;
+    method(a: string): Function;
+}
+
+class C implements I {
     method(a: number, ...b: string[]): boolean;
     method(a: string, ...b: number[]): Function;
     method(a: string): Function;
     method(a: any, ...b?: any[]) {
         throw new Error("Method not implemented.");
     }
-`);
+}`,
+});
