@@ -3,13 +3,13 @@
 // @strict: true
 
 //// class T {
-////     a: string;
+////     a: boolean;
 //// }
 
 verify.codeFix({
     description: `Add initializer to property 'a'`,
     newFileContent: `class T {
-    a: string = "";
+    a: boolean = false;
 }`,
     index: 2
 })
\ No newline at end of file
