@@ -11,7 +11,7 @@ verify.codeFix({
     description: "Declare method 'foo1'",
     index: 0,
     newRangeContent: `
-    foo1(arg0: () => number, arg1: () => string, arg2: () => boolean): any {
+    foo1(arg0: () => number, arg1: () => string, arg2: () => boolean) {
         throw new Error("Method not implemented.");
     }
     `,
@@ -22,10 +22,10 @@ verify.codeFix({
     description: "Declare method 'foo2'",
     index: 0,
     newRangeContent: `
-    foo2(arg0: (a: number) => number, arg1: (b: string) => string, arg2: (c: boolean) => boolean): any {
+    foo2(arg0: (a: number) => number, arg1: (b: string) => string, arg2: (c: boolean) => boolean) {
         throw new Error("Method not implemented.");
     }
-    foo1(arg0: () => number, arg1: () => string, arg2: () => boolean): any {
+    foo1(arg0: () => number, arg1: () => string, arg2: () => boolean) {
         throw new Error("Method not implemented.");
     }
     `,
