@@ -6,6 +6,7 @@
 ////function f(a, b) {
 ////    const x = 0; // Can't be prefixed, ignored
 ////}
+////type Length<T> = T extends ArrayLike<infer U> ? number : never;
 
 verify.codeFixAll({
     fixId: "unusedIdentifier_prefix",
@@ -13,5 +14,6 @@ verify.codeFixAll({
     newFileContent:
 `function f(_a, _b) {
     const x = 0; // Can't be prefixed, ignored
-}`,
+}
+type Length<T> = T extends ArrayLike<infer _U> ? number : never;`,
 });
