@@ -6,10 +6,4 @@
 ////function f(a: Options) { };
 ////f("/*2*/
 
-goTo.marker('1');
-verify.completionListContains("Option 1");
-verify.completionListCount(3);
-
-goTo.marker('2');
-verify.completionListContains("Option 2");
-verify.completionListCount(3);
+verify.completions({ marker: ["1", "2"], exact: ["Option 1", "Option 2", "Option 3"] });
