@@ -6,7 +6,4 @@
 ////function bar(f: Foo) { };
 ////bar({x: "/**/"});
 
-goTo.marker();
-verify.completionListContains("abc");
-verify.completionListContains("def");
-verify.completionListCount(2);
+verify.completions({ marker: "", exact: ["abc", "def"] });
