@@ -5,5 +5,7 @@
 ////function f(x: T, ...args: U[]) { };
 ////f("/*1*/", "/*2*/", "/*3*/");
 
-verify.completionsAt("1", ["foo", "bar"]);
-verify.completionsAt(["2", "3"], ["oof", "rab"]);
+verify.completions(
+    { marker: "1", exact: ["foo", "bar"] },
+    { marker: ["2", "3"], exact: ["oof", "rab"] },
+);
