@@ -13,5 +13,4 @@
 //////Test for comment
 //////c./**/
 
-goTo.marker();
-verify.completionListIsEmpty();
\ No newline at end of file
+verify.completions({ marker: "", exact: undefined });
