@@ -3,4 +3,4 @@
 ////var aa = 1;
 ////enum a { foo, /*enumValueName3*/
 
-goTo.eachMarker(() => verify.completionListIsEmpty());
+verify.completions({ marker: test.markers(), exact: undefined });
