@@ -14,15 +14,12 @@
 
 goTo.marker("c1");
 edit.insert(".");
-verify.completionListContains("x");
-verify.completionListContains("prototype");
-verify.completionListContains("staticMethod");
+verify.completions({ includes: ["x", "prototype", "staticMethod"] });
 
 goTo.marker("c2");
 edit.insert(".");
-verify.completionListIsEmpty();
+verify.completions({ exact: undefined });
 
 goTo.marker("c3");
 edit.insert(".");
-verify.completionListContains("doStuff");
-verify.completionListCount(1);
+verify.completions({ exact: "doStuff" });
