@@ -11,4 +11,4 @@
 // @Filename: /a.ts
 ////import { /**/ } from "foo";
 
-verify.completionsAt("", ["Static"]);
+verify.completions({ marker: "", exact: "Static" });
