@@ -17,14 +17,8 @@
 ////interface test3 extends IFoo./*3*/ {}
 
 ////interface test4 implements Foo./*4*/ {}
-goTo.marker("1");
-verify.not.completionListIsEmpty();
 
-goTo.marker("2");
-verify.completionListIsEmpty();
-
-goTo.marker("3");
-verify.completionListIsEmpty();
-
-goTo.marker("4");
-verify.completionListIsEmpty();
\ No newline at end of file
+verify.completions(
+    { marker: "1", exact: ["prototype", "staticMethod", ...completion.functionMembers] },
+    { marker: ["2", "3", "4"], exact: undefined },
+);
