@@ -2,5 +2,4 @@
 
 ////xyz => x/*1*/y
 
-goTo.marker("1");
-verify.completionListContains("xyz");
\ No newline at end of file
+verify.completions({ marker: "1", includes: "xyz" });
