@@ -12,9 +12,4 @@
 ////var foo: J;
 ////var { property1: { propertyOfI_1, }, /**/ } = foo;
 
-goTo.marker();
-verify.completionListContains("property2");
-verify.not.completionListContains("property1");
-verify.not.completionListContains("propertyOfI_2");
-verify.not.completionListContains("propertyOfI_1");
-verify.not.completionListAllowsNewIdentifier();
\ No newline at end of file
+verify.completions({ marker: "", exact: ["property2"] });
