@@ -8,6 +8,4 @@
 ////        var v = (p: /*1*/
 ////}
 
-goTo.marker("1");
-
-verify.completionListContains("MyType");
\ No newline at end of file
+verify.completions({ marker: "1", includes: "MyType" });
