@@ -9,6 +9,4 @@
 ////    }
 ////}
 
-goTo.marker("1");
-
-verify.completionListContains("MyType");
\ No newline at end of file
+verify.completions({ marker: "1", includes: "MyType" });
