@@ -8,14 +8,14 @@
 ////f</*1b*/T/*2b*/y/*3b*/;
 ////f</*1c*/T/*2c*/y/*3c*/>
 ////f</*1d*/T/*2d*/y/*3d*/>
-////f</*1eTypeOnly*/T/*2eTypeOnly*/y/*3eTypeOnly*/>();
+////f</*1e*/T/*2e*/y/*3e*/>();
 ////
 ////f2</*1k*/T/*2k*/y/*3k*/,
 ////f2</*1l*/T/*2l*/y/*3l*/,{| "newId": true |}T{| "newId": true |}y{| "newId": true |}
 ////f2</*1m*/T/*2m*/y/*3m*/,{| "newId": true |}T{| "newId": true |}y{| "newId": true |};
 ////f2</*1n*/T/*2n*/y/*3n*/,{| "newId": true |}T{| "newId": true |}y{| "newId": true |}>
 ////f2</*1o*/T/*2o*/y/*3o*/,{| "newId": true |}T{| "newId": true |}y{| "newId": true |}>
-////f2</*1pTypeOnly*/T/*2pTypeOnly*/y/*3pTypeOnly*/,{| "newId": true, "typeOnly": true |}T{| "newId": true, "typeOnly": true |}y{| "newId": true, "typeOnly": true |}>();
+////f2</*1p*/T/*2p*/y/*3p*/,{| "newId": true, "typeOnly": true |}T{| "newId": true, "typeOnly": true |}y{| "newId": true, "typeOnly": true |}>();
 ////
 ////f2<typeof /*1uValueOnly*/x, {| "newId": true |}T{| "newId": true |}y{| "newId": true |}
 ////
@@ -25,12 +25,11 @@
 
 goTo.eachMarker(marker => {
     const markerName = test.markerName(marker) || "";
-    const typeOnly = markerName.endsWith("TypeOnly") || marker.data && marker.data.typeOnly;
     const valueOnly = markerName.endsWith("ValueOnly");
     verify.completions({
         marker,
-        includes: typeOnly ? "Type" : valueOnly ? "x" : ["Type", "x"],
-        excludes: typeOnly ? "x" : valueOnly ? "Type" : [],
+        includes: valueOnly ? "x" : "Type",
+        excludes: valueOnly ? "Type" : "x",
         isNewIdentifierLocation: marker.data && marker.data.newId || false,
     });
 });
