@@ -9,6 +9,4 @@
 ////import p = M.N;
 ////p./**/
 
-goTo.marker();
-verify.completionListContains('foo');
-verify.not.completionListContains('bar');
\ No newline at end of file
+verify.completions({ marker: "", exact: "foo" });
