@@ -3,5 +3,4 @@
 //// declare function Foo(arg1?: Function): { q: number };
 //// Foo(function () { } )./**/;
 
-goTo.marker();
-verify.completionListContains('q');
+verify.completions({ marker: "", exact: "q" });
