@@ -16,6 +16,7 @@
 ////var zz = </*typeExpr2*/point>{ x: 4, y: 3 };
 
 const values: ReadonlyArray<FourSlashInterface.ExpectedCompletionEntry> = [
+    completion.globalThisEntry,
     { name: "m2", text: "namespace m2" }, // With no type side, allowed only in value
     { name: "m3", text: "namespace m3" },
     { name: "xx", text: "var xx: number" },
@@ -23,11 +24,12 @@ const values: ReadonlyArray<FourSlashInterface.ExpectedCompletionEntry> = [
     { name: "yy", text: "var yy: point" },
     { name: "kk", text: "var kk: m3.point3" },
     { name: "zz", text: "var zz: point" },
-    "undefined",
+    completion.undefinedVarEntry,
     ...completion.statementKeywordsWithTypes,
 ];
 
 const types: ReadonlyArray<FourSlashInterface.ExpectedCompletionEntry> = [
+    completion.globalThisEntry,
     { name: "m", text: "namespace m" },
     { name: "m3", text: "namespace m3" },
     { name: "point", text: "interface point" },
