@@ -17,7 +17,16 @@
 verify.completions({
     marker: "",
     includes: ["bdf", "abcdef", "BDF"].map(name =>
-        ({ name, source: "/a", text: `function ${name}(): void`, hasAction: true, kind: "function", kindModifiers: "export", sourceDisplay: "./a" })),
+        ({
+            name,
+            source: "/a",
+            text: `function ${name}(): void`,
+            hasAction: true,
+            kind: "function",
+            kindModifiers: "export",
+            sourceDisplay: "./a",
+            sortText: completion.SortText.AutoImportSuggestions
+        })),
     excludes: ["abcde", "dbf"],
     preferences: { includeCompletionsForModuleExports: true },
 })
