@@ -19,9 +19,13 @@
 ////    }
 ////}
 
-goTo.marker("1");
-verify.completionListCount(1);
-verify.completionListContains("foo", "(JSX attribute) foo: string", "Doc", "JSX attribute");
-goTo.marker("2");
-verify.completionListCount(1);
-verify.completionListContains("foo", "(JSX attribute) foo: string", "Doc", "JSX attribute");
+verify.completions({
+    marker: ["1", "2"],
+    exact: {
+        name: "foo",
+        text: "(JSX attribute) foo: string",
+        documentation: "Doc",
+        kind: "JSX attribute",
+        kindModifiers: "declare",
+    },
+});
