@@ -9,8 +9,8 @@ verify.completions({
     marker: "",
     includes: [
         { name: "x", text: "(parameter) x: number", kind: "parameter", insertText: "{x}" },
-        { name: "p", text: "(JSX attribute) p: number", kind: "JSX attribute", insertText: "{this.p}" },
-        { name: "a b", text: '(JSX attribute) "a b": number', kind: "JSX attribute", insertText: '{this["a b"]}' },
+        { name: "p", text: "(JSX attribute) p: number", kind: "JSX attribute", insertText: "{this.p}", sortText: completion.SortText.SuggestedClassMembers },
+        { name: "a b", text: '(JSX attribute) "a b": number', kind: "JSX attribute", insertText: '{this["a b"]}', sortText: completion.SortText.SuggestedClassMembers },
     ],
     preferences: {
         includeInsertTextCompletions: true,
