@@ -9,4 +9,4 @@
 // @Filename: /project/index.ts
 ////import { } from ".//**/";
 
-verify.completionsAt("", [], { isNewIdentifierLocation: true });
\ No newline at end of file
+verify.completions({ marker: "", exact: [], isNewIdentifierLocation: true });
\ No newline at end of file
