@@ -16,4 +16,8 @@
 ////    }
 ////}
 
-verify.completionsAt("", ["x"], { isNewIdentifierLocation: true });
+verify.completions({
+    marker: "",
+    exact: { name: "x", kind: "script", kindModifiers: ".ts" },
+    isNewIdentifierLocation: true,
+});
