@@ -2,13 +2,14 @@
 
 // @allowNonTsExtensions: true
 // @Filename: test123.js
+// @lib: es5
 ////export function /**/MyClass() {
 ////}
 ////MyClass.prototype.foo = async function() {
-////    await 2;
+////    await Promise.resolve();
 ////}
 ////MyClass.bar = async function() {
-////    await 3;
+////    await Promise.resolve();
 ////}
 
 verify.codeFix({
@@ -18,10 +19,10 @@ verify.codeFix({
     constructor() {
     }
     async foo() {
-        await 2;
+        await Promise.resolve();
     }
     static async bar() {
-        await 3;
+        await Promise.resolve();
     }
 }
 `,
