@@ -2,13 +2,14 @@
 
 // @allowNonTsExtensions: true
 // @Filename: test123.js
-////export const /**/foo = function() {
+////export const foo = function() {
 ////};
 ////foo.prototype.instanceMethod = function() {
 ////};
 
-verify.applicableRefactorAvailableAtMarker("");
-verify.fileAfterApplyingRefactorAtMarker("",
+verify.codeFix({
+    description: "Convert function to an ES2015 class",
+    newFileContent:
 `export class foo {
     constructor() {
     }
@@ -16,4 +17,4 @@ verify.fileAfterApplyingRefactorAtMarker("",
     }
 }
 `,
-'Convert to ES2015 class', 'convert');
+});
