@@ -7,8 +7,9 @@
 ////    try {} catch() {}
 ////}
 
-verify.applicableRefactorAvailableAtMarker("");
-verify.fileAfterApplyingRefactorAtMarker("",
+verify.codeFix({
+    description: "Convert function to an ES2015 class",
+    newFileContent:
 `class MyClass {
     constructor() { }
     foo() {
@@ -17,4 +18,4 @@ verify.fileAfterApplyingRefactorAtMarker("",
     }
 }
 `,
-'Convert to ES2015 class', 'convert');
+});
