@@ -10,6 +10,8 @@ const multiLineOffset = 12;
 ////    }
 ////    /*1*/
 ////    [1 + 2 + 3 + Math.rand()](x: number, y: string, z = true) { }
+////    /*2*/
+////    m: function(a) {}
 ////}
 
 verify.docCommentTemplateAt("0", singleLineOffset, "/** */");
@@ -21,3 +23,9 @@ verify.docCommentTemplateAt("1", multiLineOffset,
      * @param y
      * @param z
      */`);
+    
+verify.docCommentTemplateAt("2", multiLineOffset,
+   `/**
+     * 
+     * @param a
+     */`);
