@@ -6,10 +6,10 @@
 
 // @Filename: /a.d.ts
 ////export as namespace abc;
-////export const [|{| "isWriteAccess": true, "isDefinition": true |}x|]: number;
+////[|export const [|{| "isWriteAccess": true, "isDefinition": true, "contextRangeIndex": 0 |}x|]: number;|]
 
 // @Filename: /b.ts
 ////import a from "./a";
 ////a.[|x|];
 
-verify.singleReferenceGroup('const x: number');
+verify.singleReferenceGroup('const x: number', "x");
