@@ -8,16 +8,18 @@
 
 goTo.select('a', 'b')
 edit.applyRefactor({
-    refactorName: "Extract Method",
-    actionName: "scope_1",
-    actionDescription: "Extract function into global scope",
-});
-verify.currentFileContentIs(`function M() {
+    refactorName: "Extract Symbol",
+    actionName: "function_scope_1",
+    actionDescription: "Extract to function in global scope",
+    newContent:
+`function M() {
     let a = [1,2,3];
     let x = 0;
-    console.log(newFunction(a, x));
+    console.log(/*RENAME*/newFunction(a, x));
 }
+
 function newFunction(a: number[], x: number): any {
     return a[x];
 }
-`);
\ No newline at end of file
+`
+});
