@@ -2,9 +2,9 @@
 
 //// class B {}
 //// function foo() {
-////     return {[|{| "isWriteAccess": true, "isDefinition": true |}B|]: B};
+////     return {[|[|{| "isWriteAccess": true, "isDefinition": true, "contextRangeIndex": 0 |}B|]: B|]};
 //// }
 //// class C extends (foo()).[|B|] {}
 //// class C1 extends foo().[|B|] {}
 
-verify.singleReferenceGroup("(property) B: typeof B");
+verify.singleReferenceGroup("(property) B: typeof B", "B");
